@@ -48,7 +48,7 @@ typedef struct _tSaveGameSlots
 	int year;
 	int month;
 	int day;
-	
+
 	int hour;
 	int minute;
 	int sec;
@@ -84,7 +84,7 @@ typedef	struct _tContext
 	int	echomode;
 
 	int	capital;	// =1 if the next character should be a capital letter.
-	int	lastchar;	
+	int	lastchar;
 	int	jinxterslide;	// THIS workaround makes the sliding puzzle in Jinxter solvable
 	int headlineflagged;
 	char	low_ansi_characters[128];	// characters that are allowed for low ansi rendering
@@ -109,7 +109,7 @@ typedef	struct _tContext
 
 #ifdef	EXPERIMENTAL_SAVEGAME_SLOTS
 	tSaveGameSlots	saveGameSlots[10];
-	char advancedSavesFilename[1024];	
+	char advancedSavesFilename[1024];
 #endif
 } tContext;
 
@@ -128,7 +128,7 @@ int default_printline(char* text,int startidx,int endidx,int spaceidx,int column
 	{
 		endidx=spaceidx;	// otherwise, there is a word after which the line ends.
 	}
-	endidx--;	// the last character was either a space or a newline	
+	endidx--;	// the last character was either a space or a newline
 	delta=columns-endidx+startidx;	// how much 'room' is there?
 
 	if (alignment==ALIGNMENT_RIGHT && delta<(columns-1))	// in right alignment
@@ -136,7 +136,7 @@ int default_printline(char* text,int startidx,int endidx,int spaceidx,int column
 		if (newline) delta++;
 		for (i=0;i<delta;i++)	// fill the beginning of the line
 		{
-			printf(" ");	
+			printf(" ");
 		}
 	}
 	spaces=0;
@@ -144,7 +144,7 @@ int default_printline(char* text,int startidx,int endidx,int spaceidx,int column
 	for (i=startidx;i<endidx;i++)
 	{
 		c=text[i];
-		if (c==' ') spaces++;	
+		if (c==' ') spaces++;
 	}
 	{
 		int accu;
@@ -168,8 +168,8 @@ int default_printline(char* text,int startidx,int endidx,int spaceidx,int column
 			outcnt++;
 		}
 	}
-	if (!end) printf("\n");	
-	return 0;	
+	if (!end) printf("\n");
+	return 0;
 }
 int default_cbNewOutput(void* context,char* headline,char* text,char* picname)
 {
@@ -178,7 +178,7 @@ int default_cbNewOutput(void* context,char* headline,char* text,char* picname)
 //	printf("\x1b[1;37;41m%s\x1b[0m\n",headline);
 //	printf("\x1b[1;37;42m%s\x1b[0m\n",text);
 //	printf("\x1b[1;47;44m%s\x1b[0m\n",picname);
-	
+
 	if (headline[0])	// when there is a headline, print it
 	{
 		if (pContext->mode==eMODE_NONE)
@@ -290,11 +290,10 @@ int default_cbDrawPicture(void* context,tdMagneticPicture* picture,char* picname
 	if (pContext->mode==eMODE_NONE) return 0;
 	// flush the output buffer
 	printf("\n");
-	retval=0;
 	switch (pContext->mode)
 	{
 		case eMODE_MONOCHROME:
-			retval=default_render_monochrome(pContext->monochrome_characters,pContext->monochrome_inverted,picture,pContext->rows,pContext->columns);	
+			retval=default_render_monochrome(pContext->monochrome_characters,pContext->monochrome_inverted,picture,pContext->rows,pContext->columns);
 			break;
 		case eMODE_LOW_ANSI:
 			retval=default_render_lowansi(pContext->low_ansi_characters,picture,pContext->rows,pContext->columns);
@@ -324,7 +323,7 @@ int default_setEngine(void* context,void *hEngine)
 	tContext *pContext=(tContext*)context;
 
 	pContext->hEngine=hEngine;
-	return 0;	
+	return 0;
 }
 #ifdef	 EXPERIMENTAL_SAVEGAME_SLOTS
 
@@ -442,7 +441,7 @@ int default_cbSaveGame(void* context,char* filename,void* ptr,int len)
 			printf("Unable to open file [%s]\n",(char*)ptr);
 			return 0;
 		}
-		n=fwrite(ptr,sizeof(char),len,f);	
+		n=fwrite(ptr,sizeof(char),len,f);
 		fclose(f);
 		if (n!=len) retval=-1;
 	}
@@ -536,7 +535,7 @@ int default_cbLoadGame(void* context,char* filename,void* ptr,int len)
 			printf("Unable to open file [%s]\n",(char*)ptr);
 			return 0;
 		}
-		n=fread(ptr,sizeof(char),len,f);	
+		n=fread(ptr,sizeof(char),len,f);
 		fclose(f);
 		if (n!=len) retval=-1;
 	}
@@ -644,7 +643,7 @@ int default_open(void* hContext,FILE *f_inifile,int argc,char** argv)
 		}
 		if (retrievefromini(f_inifile,"[DEFAULTGUI]","mode",result,sizeof(result)))
 		{
-			if (strncmp(result,"none",4)==0) pContext->mode=eMODE_NONE;	
+			if (strncmp(result,"none",4)==0) pContext->mode=eMODE_NONE;
 			else if (strncmp(result,"monochrome_inv",14)==0) {pContext->mode=eMODE_MONOCHROME;pContext->monochrome_inverted=1;}
 			else if (strncmp(result,"monochrome",10)==0) pContext->mode=eMODE_MONOCHROME;
 			else if (strncmp(result,"low_ansi2",9)==0) pContext->mode=eMODE_LOW_ANSI2;
@@ -662,12 +661,21 @@ int default_open(void* hContext,FILE *f_inifile,int argc,char** argv)
 		}
 		if (retrievefromini(f_inifile,"[DEFAULTGUI]","low_ansi_characters",pContext->low_ansi_characters,sizeof(pContext->low_ansi_characters)))
 		{
-		} else {
+			if (pContext->low_ansi_characters[0]==0x00) 
+			{
+				fprintf(stderr,"Error in .ini file: low_ansi_character\n");
+				return -1;
+			}
+			
 		}
 		if (retrievefromini(f_inifile,"[DEFAULTGUI]","monochrome_characters",pContext->monochrome_characters,sizeof(pContext->monochrome_characters)))
 		{
+			if (pContext->monochrome_characters[0]==0x00) 
+			{
+				fprintf(stderr,"Error in .ini file: monochrome_character\n");
+				return -1;
+			}
 
-		} else {
 		}
 		if (retrievefromini(f_inifile,"[DEFAULTGUI]","sixel_forceresolution",result,sizeof(result)))
 		{
@@ -699,7 +707,7 @@ int default_open(void* hContext,FILE *f_inifile,int argc,char** argv)
 		{
 			if (result[0]=='c' || result[0]=='C') pContext->advancedSaves=0;	// "classic" or "Classic"
 			if (result[0]=='a' || result[0]=='A') pContext->advancedSaves=1;	// "advanced" or "Advanced"
-		}	
+		}
 	}
 	if (argc)
 	{
@@ -714,13 +722,13 @@ int default_open(void* hContext,FILE *f_inifile,int argc,char** argv)
 				printf("left ");
 				printf("block ");
 				printf("right ");
-				printf("\n");	
+				printf("\n");
 				return DEFAULT_NOK;
-			}	
+			}
 		}
 		if (retrievefromcommandline(argc,argv,"-vmode",result,sizeof(result)))
 		{
-			if (strncmp(result,"none",4)==0) pContext->mode=eMODE_NONE;	
+			if (strncmp(result,"none",4)==0) pContext->mode=eMODE_NONE;
 			else if (strncmp(result,"monochrome_inv",14)==0) {pContext->mode=eMODE_MONOCHROME;pContext->monochrome_inverted=1;}
 			else if (strncmp(result,"monochrome",10)==0) pContext->mode=eMODE_MONOCHROME;
 			else if (strncmp(result,"low_ansi2",9)==0) pContext->mode=eMODE_LOW_ANSI2;
@@ -740,9 +748,9 @@ int default_open(void* hContext,FILE *f_inifile,int argc,char** argv)
 				printf("high_ansi2 ");
 				printf("sixel ");
 				printf("utf ");
-				printf("\n");	
+				printf("\n");
 				return DEFAULT_NOK;
-			}	
+			}
 		}
 		if (retrievefromcommandline(argc,argv,"-vrows",result,sizeof(result)))
 		{
@@ -773,7 +781,7 @@ int default_open(void* hContext,FILE *f_inifile,int argc,char** argv)
 		if (retrievefromcommandline(argc,argv,"-vlog",result,sizeof(result)))
 		{
 			fprintf(stderr,"Opening logfile [%s] for writing\n",result);
-			pContext->f_logfile=fopen(result,"wb");	
+			pContext->f_logfile=fopen(result,"wb");
 			if (pContext->f_logfile==NULL)
 			{
 				fprintf(stderr,"Error opening logfile [%s]\n",result);
@@ -821,5 +829,5 @@ int default_open(void* hContext,FILE *f_inifile,int argc,char** argv)
 #endif
 	}
 	return DEFAULT_OK;
-	
+
 }
