@@ -129,43 +129,42 @@ const unsigned long long asciibitmap[95]={
 	0x00380c0c070c0c38, // {
 	0x0018181800181818, // |
 	0x00070c0c380c0c07, // }
-      0x0000000000003b6e // ~
+	0x0000000000003b6e // ~
 };
 
 int default_render_lowansi(char* allowed,tdMagneticPicture* picture,int rows,int cols)
 {
-	unsigned char maxplut[16]={0};	
+	unsigned char maxplut[16]={0};
 
 
-	int cnt0;
 	int x,y,a,c,i,j,k,p;	// counting variables
 	int minccnt,maxc;
 	int maxpcnt,maxp;
-	int accux,accuy;
-	cnt0=0;
+	int accuy;
 	// step one:	// find a good substitute for the palette.
 	if (picture->pictureType==PICTURE_C64)
 	{
 		// the c64 had a fixed palette.
-	
+
 		maxplut[ 0]=0x0;maxplut[ 1]=0xe;maxplut[ 2]=0x1;maxplut[ 3]=0x6;	// black, white, red, cyan
 		maxplut[ 4]=0x5;maxplut[ 5]=0x2;maxplut[ 6]=0x4;maxplut[ 7]=0xb;	// purple, green, blue, yellow
 		maxplut[ 8]=0x9;maxplut[ 9]=0x3;maxplut[10]=0xd;maxplut[11]=0x8;	// orange, brown, pink, dark grey
 		maxplut[12]=0x7;maxplut[13]=0xa;maxplut[14]=0xc;maxplut[15]=0xf;	// medium grey, light green, light blue, light grey
-		
+
 	} else {
 		default_palette(picture,maxplut);
 	}
 
 	// step 2: render the picture. use the color and the character that best represents a 8x8 block.
 	y=0;
-	accux=accuy=0;
+	accuy=0;
 	for (i=0;i<picture->height;i++)
 	{
 		accuy+=rows;	// since the output is smaller than the actual picture, count a few lines.
 				// at some point, there are enough to print one character.
 		if (accuy>=picture->height)
 		{
+			int accux;
 			int lastmaxp;
 			lastmaxp=-1;
 			accux=0;
@@ -174,7 +173,7 @@ int default_render_lowansi(char* allowed,tdMagneticPicture* picture,int rows,int
 			{
 				accux+=cols;
 				if (accux>=picture->width)
-				{	
+				{
 					unsigned long long pb;
 					int scalex,scaley;
 
@@ -190,6 +189,7 @@ int default_render_lowansi(char* allowed,tdMagneticPicture* picture,int rows,int
 					maxpcnt=0;
 					for (p=0;p<16;p++)
 					{
+						int cnt0;
 						int x2,y2;
 						cnt0=0;
 						for (x2=x;x2<j;x2++)
@@ -231,6 +231,7 @@ int default_render_lowansi(char* allowed,tdMagneticPicture* picture,int rows,int
 					maxc=0;
 					for (a=0;a<strlen(allowed);a++)
 					{
+						int cnt0;
 						unsigned long long cb;
 						c=allowed[a];	// character
 						cb=pb^asciibitmap[c-32];	// cb is the comparision of the bitmap for this character with the one for the 8x8 pixel block.
@@ -246,7 +247,7 @@ int default_render_lowansi(char* allowed,tdMagneticPicture* picture,int rows,int
 							maxc=c;
 						}
 					}
-	
+
 					maxp=maxplut[maxp];
 					if (maxp!=lastmaxp) printf("\x1b[%d;%dm",maxp/8,30+maxp%8);
 					lastmaxp=maxp;
@@ -265,18 +266,16 @@ int default_render_lowansi(char* allowed,tdMagneticPicture* picture,int rows,int
 }
 int default_render_lowansi2(char* allowed,tdMagneticPicture* picture,int rows,int cols)
 {
-	int cnt0;
 	int x,y,a,c,i,j,k,p;	// counting variables
 	int minccnt,maxc;
 	int maxpcnt,maxp;
-	int accux,accuy;
+	int accuy;
 	int redsum,greensum,bluesum,pixcnt;
 	int lastx,lasty;
-	cnt0=0;
 	// render the picture. use the color and the character that best represents a 8x8 block.
 
 	y=0;
-	accux=accuy=0;
+	accuy=0;
 	lasty=0;
 	for (i=0;i<picture->height;i++)
 	{
@@ -284,6 +283,7 @@ int default_render_lowansi2(char* allowed,tdMagneticPicture* picture,int rows,in
 				// at some point, there are enough to print one character.
 		if (accuy>=picture->height)
 		{
+			int accux;
 			int lastmaxp;
 			lastmaxp=-1;
 			accux=0;
@@ -293,7 +293,7 @@ int default_render_lowansi2(char* allowed,tdMagneticPicture* picture,int rows,in
 			{
 				accux+=cols;
 				if (accux>=picture->width)
-				{	
+				{
 					unsigned long long pb;
 					int scalex,scaley;
 					int l;
@@ -313,12 +313,12 @@ int default_render_lowansi2(char* allowed,tdMagneticPicture* picture,int rows,in
 							pixcnt++;
 						}
 					}
-					
+
 					lastx=j;
 
 					maxp2=default_findrgbcluster(redsum/pixcnt,greensum/pixcnt,bluesum/pixcnt);
 
-					
+
 
 					if (picture->pictureType==PICTURE_HALFTONE) mul=2;
 					else mul=1;
@@ -334,6 +334,7 @@ int default_render_lowansi2(char* allowed,tdMagneticPicture* picture,int rows,in
 					maxpcnt=0;
 					for (p=0;p<16;p++)
 					{
+						int cnt0;
 						int x2,y2;
 						cnt0=0;
 						for (x2=x;x2<j;x2+=mul)
@@ -375,6 +376,7 @@ int default_render_lowansi2(char* allowed,tdMagneticPicture* picture,int rows,in
 					maxc=0;
 					for (a=0;a<strlen(allowed);a++)
 					{
+						int cnt0;
 						unsigned long long cb;
 						c=allowed[a];	// character
 						cb=pb^asciibitmap[c-32];	// cb is the comparision of the bitmap for this character with the one for the 8x8 pixel block.
@@ -390,7 +392,7 @@ int default_render_lowansi2(char* allowed,tdMagneticPicture* picture,int rows,in
 							maxc=c;
 						}
 					}
-	
+
 					if (maxp2!=lastmaxp) printf("\x1b[%d;%dm",maxp2/8,30+maxp2%8);
 					lastmaxp=maxp2;
 					if (maxc<32 || maxc>=127) printf(" ");
@@ -429,7 +431,7 @@ int default_render_monochrome(char* greyscales,int inverted,tdMagneticPicture* p
 	mingrey=maxgrey=0;
 	p=0;
 	for (pass=0;pass<2;pass++)
-	{	
+	{
 		if (pass==1 && mingrey==maxgrey)
 		{
 			maxgrey++;
@@ -450,7 +452,7 @@ int default_render_monochrome(char* greyscales,int inverted,tdMagneticPicture* p
 					if (accux>=picture->width || j==picture->width-1)
 					{
 						x_right=j+1;
-						accux-=picture->width;		
+						accux-=picture->width;
 						// at this point, a rectangle between y_up,y_down, x_left,x_right contains the pixels that need to be greyscaled.
 						grey=0;
 						pixcnt=0;
@@ -460,7 +462,7 @@ int default_render_monochrome(char* greyscales,int inverted,tdMagneticPicture* p
 							{
 								if (k<picture->height && l<picture->width)
 								{
-									p=picture->pixels[k*picture->width+l];	
+									p=picture->pixels[k*picture->width+l];
 								}
 								// compensate for luminance (0.2126*R + 0.7152*G + 0.0722*B)
 								grey+=2126*(PICTURE_GET_RED(picture->palette[p]));
@@ -488,8 +490,10 @@ int default_render_monochrome(char* greyscales,int inverted,tdMagneticPicture* p
 							if (inverted) grey=scalenum-1-grey;
 							if (grey<0) grey=0;
 							if (grey>=scalenum) grey=scalenum-1;
-							printf("%c",greyscales[grey]);
-
+							if(strlen(greyscales))
+							{
+								printf("%c",greyscales[grey%strlen(greyscales)]);
+							}
 						}
 						x_left=x_right;
 					}
@@ -505,22 +509,12 @@ int default_render_monochrome(char* greyscales,int inverted,tdMagneticPicture* p
 int default_render_highansi(tdMagneticPicture *picture,int rows,int columns,int blur)
 {
 	int i,j;
-	int accux,accuy;
-	int red,green,blue;
-	int lastx;
+	int accuy;
 	int lasty;
-	int pixcnt;
-
-	red=0;
-	green=0;
-	blue=0;
-
-	lastx=lasty=0;
-	pixcnt=0;
 
 
-
-	accux=accuy=0; 
+	lasty=0;
+	accuy=0; 
 
 	for (i=0;i<picture->height;i++)
 	{
@@ -529,6 +523,8 @@ int default_render_highansi(tdMagneticPicture *picture,int rows,int columns,int
 		lastrgb=-1;
 		if (accuy>=picture->height || i==picture->height-1)
 		{
+			int accux;
+			int lastx;
 			accuy-=picture->height;
 			accux=0;
 			lastx=0;
@@ -537,7 +533,9 @@ int default_render_highansi(tdMagneticPicture *picture,int rows,int columns,int
 				accux+=columns;
 				if (accux>=picture->width || j==picture->width-1)
 				{
+					int red,green,blue;
 					int x,y;
+					int pixcnt;
 					red=0;
 					green=0;
 					blue=0;
@@ -569,6 +567,7 @@ int default_render_highansi(tdMagneticPicture *picture,int rows,int columns,int
 					}
 					if (rgb!=lastrgb)
 					{
+						int red,green,blue;
 						red  =PICTURE_GET_RED(rgb);
 						green=PICTURE_GET_GREEN(rgb);
 						blue =PICTURE_GET_BLUE(rgb);
@@ -603,15 +602,15 @@ int default_render_sixel(tdMagneticPicture* picture,int screenwidth,int screenhe
 #define	BACKGROUND_POSITION	15
 #define	TOTAL_COLOURS		16
 	int i,j;
-	int accux,accuy;
-	int x,y;
+	int accuy;
+	int y;
 	int minval=0;
 	int minpos=0;
 	int maxval=0;
 	int maxpos=0;
 	int paletteorder[TOTAL_COLOURS];
-	x=0;y=0;
-	accux=accuy=0;
+	y=0;
+	accuy=0;
 
 	// find a good aspect ratio
 	{
@@ -654,13 +653,13 @@ int default_render_sixel(tdMagneticPicture* picture,int screenwidth,int screenhe
 			{
 				minval=val;
 				minpos=i;
-			}	
+			}
 
 			if (i==0 || maxval<val)
 			{
 				maxval=val;
 				maxpos=i;
-			}	
+			}
 		}
 		// according to james, the background colour will be changed in some terminals
 		// as well as the default foreground value. presumably, because they only had
@@ -708,6 +707,7 @@ int default_render_sixel(tdMagneticPicture* picture,int screenwidth,int screenhe
 		y0=y;
 		for (i=0;i<TOTAL_COLOURS;i++)
 		{
+			int x,accux;
 			printf("#%02d",i);
 			x=0;
 			accux=0;
@@ -791,12 +791,12 @@ int default_render_utf(tdMagneticPicture* picture,int rows,int cols)
 		accuy+=rows;
 		if (accuy>=picture->height)
 		{
+			unsigned int lastfg,lastbg;
+			lastfg=lastbg=0xffffffff;
 			accuy-=picture->height;
-			accux=0;	
+			accux=0;
 			for (x=0;x<picture->width;x++)
 			{
-				unsigned int lastfg,lastbg;
-				lastfg=lastbg=0xffffffff;
 				accux+=cols;
 				if (accux>=picture->width)
 				{
