@@ -53,7 +53,7 @@ int cbDumpPicture(void* context,tdMagneticPicture* pPicture,char* picname,int mo
 	int j;
 	FILE *f;
 	char filename[1024];
-	
+
 	snprintf(filename,1024,"%s%s.xpm",(char*)context,picname);
 
 	f=fopen(filename,"wb");
@@ -75,34 +75,38 @@ int cbDumpPicture(void* context,tdMagneticPicture* pPicture,char* picname,int mo
 		blue =(pPicture->palette[i]>>(0*PICTURE_BITS_PER_RGB_CHANNEL))&PICTURE_MAX_RGB_VALUE;
 		red*=0xff;green*=0xff;blue*=0xff;
 		red/=PICTURE_MAX_RGB_VALUE;green/=PICTURE_MAX_RGB_VALUE;blue/=PICTURE_MAX_RGB_VALUE;
-		
+
 		fprintf(f,"\"%x c #%02X%02X%02X\",\n",i,red,green,blue);
 	}
-        fprintf(f,"/* pixels */\n");
-        for (i=0;i<pPicture->height;i++)
-        {
-                fprintf(f,"\"");
-                for (j=0;j<pPicture->width;j++)
-                {
-                        fprintf(f,"%x",pPicture->pixels[i*pPicture->width+j]);
-                }
-                fprintf(f,"\"");
-                if (i!=(pPicture->height-1)) fprintf(f,",");
-                fprintf(f,"\n");
-        }
-        fprintf(f,"};\n");
+	fprintf(f,"/* pixels */\n");
+	for (i=0;i<pPicture->height;i++)
+	{
+		fprintf(f,"\"");
+		for (j=0;j<pPicture->width;j++)
+		{
+			fprintf(f,"%x",pPicture->pixels[i*pPicture->width+j]);
+		}
+		fprintf(f,"\"");
+		if (i!=(pPicture->height-1)) fprintf(f,",");
+		fprintf(f,"\n");
+	}
+	fprintf(f,"};\n");
 	fclose(f);
-	
+
 	return 0;
 }
 
 int init(int argc,char** argv,FILE *f_inifile,
-int *pNodoc,
-eBinType* pBinType,char* magfilename,char* gfxfilename,char* binfilename)
+		int *pNodoc,
+		eBinType* pBinType,char* magfilename,char* gfxfilename,char* binfilename)
 {
-	
+
 	int gamenamegiven;
 	int retval;
+	if (magfilename==NULL || gfxfilename==NULL || binfilename==NULL)
+	{
+		return -1;
+	}
 
 	*pNodoc=0;
 	*pBinType=BINTYPE_NONE;
@@ -253,7 +257,38 @@ eBinType* pBinType,char* magfilename,char* gfxfilename,char* binfilename)
 			*pNodoc=1;
 		}
 	}
-	if (magfilename[0]==0 && gfxfilename[0]==0 && binfilename[0]==0) retval=-1;
+	if (magfilename[0]==0 && gfxfilename[0]==0 && binfilename[0]==0) 
+	{
+		int i;
+		eFileType fileType;
+		// last chance:
+		// check if the commandline had a .mag or .gfx file referenced directly
+		retval=-1;
+		for (i=1;i<argc;i++)
+		{
+			maggfxguesstype(argv[i],&fileType);
+			if (fileType==FILETYPE_MAG) 
+			{
+				int l;
+				l=strlen(argv[i]);
+				if (l>=MAXFILENAMESIZE) l=MAXFILENAMESIZE-1;
+				memcpy(magfilename,argv[i],l+1);
+				printf("Using [%s] as .mag file \n",magfilename);
+				retval=0;
+				*pBinType=BINTYPE_MAGGFX;
+			}
+			if (fileType==FILETYPE_GFX)
+			{
+				int l;
+				l=strlen(argv[i]);
+				if (l>=MAXFILENAMESIZE) l=MAXFILENAMESIZE-1;
+				memcpy(gfxfilename,argv[i],l+1);
+				printf("Using [%s] as .gfx file\n",gfxfilename);
+				retval=0;
+				*pBinType=BINTYPE_MAGGFX;
+			}
+		}
+	}
 	return retval;
 }
 int dumpmaggfx(int argc,char** argv,char* magbuf,int magsize,char* gfxbuf,int gfxsize)
@@ -311,8 +346,9 @@ int main(int argc,char** argv)
 	unsigned int random_seed;
 	int egamode;
 	int dumppics;
-	char* magbuf;	
+	char* magbuf;
 	char* gfxbuf;
+	tdMagneticPicture *picture;
 
 
 	eBinType binType;
@@ -371,20 +407,26 @@ int main(int argc,char** argv)
 		{
 			fclose(f_inifile);
 		}
-	}	
+	}
 	if (argc<2)
 	{
-		helpscreens_loaderfailed(argv[0]);
+		helpscreens_basic(argv[0],stderr,1);
+		//helpscreens_loaderfailed(argv[0]);
 		return 1;
 	}
 	if ((retrievefromcommandline(argc,argv,"--version",NULL,0))
-		|| (retrievefromcommandline(argc,argv,"-version",NULL,0))
-		|| (retrievefromcommandline(argc,argv,"-v",NULL,0)))
+			|| (retrievefromcommandline(argc,argv,"-version",NULL,0))
+			|| (retrievefromcommandline(argc,argv,"-v",NULL,0)))
 	{
 		printf("%d.%d%d\n",VERSION_MAJOR,VERSION_MINOR,VERSION_REVISION);
 		return 0;
 	}
-	if (retrievefromcommandline(argc,argv,"-bsd",NULL,0))
+	if (retrievefromcommandline(argc,argv,"-bsd",NULL,0)
+	 || retrievefromcommandline(argc,argv,"-license",NULL,0)
+	 || retrievefromcommandline(argc,argv,"-licence",NULL,0)
+	 || retrievefromcommandline(argc,argv,"--license",NULL,0)
+	 || retrievefromcommandline(argc,argv,"--licence",NULL,0)
+	)
 	{
 		helpscreens_license();
 		return 0;
@@ -392,13 +434,13 @@ int main(int argc,char** argv)
 
 	}
 	if ((retrievefromcommandline(argc,argv,"--help",NULL,0))
-	||  (retrievefromcommandline(argc,argv,"-help",NULL,0)))
+			||  (retrievefromcommandline(argc,argv,"-help",NULL,0)))
 	{
 		helpscreens_help(argv[0]);
 		return 0;
 	}
 	if ((retrievefromcommandline(argc,argv,"--helpini",NULL,0))
-	||  (retrievefromcommandline(argc,argv,"-helpini",NULL,0)))
+			||  (retrievefromcommandline(argc,argv,"-helpini",NULL,0)))
 	{
 		helpscreens_helpini();
 		return 0;
@@ -406,21 +448,23 @@ int main(int argc,char** argv)
 	if (retrievefromcommandline(argc,argv,"-ini",inifilename,sizeof(inifilename))) 
 	{
 	}
-	fprintf(stderr,"Using .ini file: %s\n",inifilename);		
+	fprintf(stderr,"Using .ini file: %s\n",inifilename);
 	f_inifile=fopen(inifilename,"rb");
 	retval=default_getsize(&sizeGUI);
 	if (retval)
 	{
 		fprintf(stderr,"ERROR. default_getsize returned %d\n",retval);
+		fclose(f_inifile);
 		return 1;
 	}
 
-//////////////////////////////////////////////////////
-// initialize the default GUI
+	//////////////////////////////////////////////////////
+	// initialize the default GUI
 	hGUI=malloc(sizeGUI);
 	if (hGUI==NULL)
 	{
 		fprintf(stderr,"ERROR: unable to locate memory for the GUI\n");
+		fclose(f_inifile);
 		return 1;
 	}
 	retval=default_open(hGUI,f_inifile,argc,argv);
@@ -429,7 +473,7 @@ int main(int argc,char** argv)
 		fprintf(stderr,"ERROR: opening the GUI failed\n");
 		return 1;
 	}
-//////////////////////////////////////////////// random
+	//////////////////////////////////////////////// random
 	random_mode=0;
 	random_seed=12345;
 	if (f_inifile)
@@ -457,7 +501,7 @@ int main(int argc,char** argv)
 			}
 		}
 	}
-		
+
 
 	if (argc)
 	{
@@ -483,7 +527,7 @@ int main(int argc,char** argv)
 				return 1;
 			}
 		}
-	}	
+	}
 	egamode=0;
 	if (f_inifile)
 	{
@@ -508,10 +552,14 @@ int main(int argc,char** argv)
 	if (f_inifile) fclose(f_inifile);
 	magbuf=malloc(MAXMAGSIZE);
 	gfxbuf=malloc(MAXGFXSIZE);
-	
+	picture=malloc(sizeof(tdMagneticPicture));
+
 	if (magbuf==NULL || gfxbuf==NULL) 
 	{
 		fprintf(stderr,"ERROR: unable to allocate memory for the data files\n");
+		if (picture!=NULL) free(picture);
+		if (magbuf!=NULL) free(magbuf);
+		if (gfxbuf!=NULL) free(gfxbuf);
 		return -1;
 	}
 
@@ -521,10 +569,22 @@ int main(int argc,char** argv)
 	if (init(argc,argv,f_inifile,&nodoc,&binType,magfilename,gfxfilename,binfilename))
 	{
 		helpscreens_loaderfailed(argv[0]);
+		free(picture);
+		free(magbuf);
+		free(gfxbuf);
+		fclose(f_inifile);
 		return 1;
 	}
 	retval=dMagnetic_getsize(&handlesize,64);
 	hEngine=malloc(handlesize);
+	if (retval || hEngine==NULL)
+	{
+		fprintf(stderr,"Unable to allocate memory for backend\n");
+		free(picture);
+		free(magbuf);
+		free(gfxbuf);
+		fclose(f_inifile);
+	}
 	default_setEngine(hGUI,hEngine);
 	do
 	{
@@ -547,23 +607,23 @@ int main(int argc,char** argv)
 		}
 
 		dMagnetic_init(hEngine,64,magbuf,magsize,gfxbuf,gfxsize);	// the buffer have been filled. 
-	
+
 		if (dumppics)
 		{
-			retval=dMagnetic_setCBdrawPicture(hEngine,cbDumpPicture,"");
-			retval=dMagnetic_dumppics(hEngine);
+			retval=dMagnetic_setCBdrawPicture(hEngine,cbDumpPicture,"",picture);
+			retval|=dMagnetic_dumppics(hEngine);
 			return retval;
 		}
-		
+
 		retval=0;
 		// configure after the reinit
-		retval|=dMagnetic_configrandom(hEngine,random_mode,random_seed);	
-		retval|=dMagnetic_setEGAMode(hEngine,egamode);				
+		retval|=dMagnetic_configrandom(hEngine,random_mode,random_seed);
+		retval|=dMagnetic_setEGAMode(hEngine,egamode);
 		// set the call back hooks for this GUI
 
 		retval|=dMagnetic_setCBnewOutput(hEngine,default_cbNewOutput,hGUI);
 		retval|=dMagnetic_setCBinputString(hEngine,default_cbInputString,	hGUI);
-		retval|=dMagnetic_setCBdrawPicture(hEngine,default_cbDrawPicture,	hGUI);
+		retval|=dMagnetic_setCBdrawPicture(hEngine,default_cbDrawPicture,	hGUI,picture);
 		retval|=dMagnetic_setCBloadGame(hEngine,default_cbLoadGame,		hGUI);
 		retval|=dMagnetic_setCBsaveGame(hEngine,default_cbSaveGame,		hGUI);
 
@@ -577,7 +637,7 @@ int main(int argc,char** argv)
 		{
 			int version;
 			retval=dMagnetic_getGameVersion(hEngine,&version);
-			if (version==4)
+			if (version==4 && retval==0)
 			{
 				fprintf(stderr,"\n");
 				fprintf(stderr,"---------------------------------------\n");
@@ -600,12 +660,12 @@ int main(int argc,char** argv)
 			dMagnetic_getVMstate(hEngine,&vmState);
 			fprintf(stderr,"Unknown opcode %04X \n",((unsigned int)vmState.lastOpcode)&0xffff);
 			fprintf(stderr,"PCR=0x%08X SR=0x%02X %c%c%c%c%c\n",vmState.pcr,vmState.sr,
-				(vmState.sr&0x10)?'X':'x',
-				(vmState.sr&0x08)?'N':'n',
-				(vmState.sr&0x04)?'Z':'z',
-				(vmState.sr&0x02)?'V':'v',
-				(vmState.sr&0x01)?'C':'c'
-				);//cvznx
+					(vmState.sr&0x10)?'X':'x',
+					(vmState.sr&0x08)?'N':'n',
+					(vmState.sr&0x04)?'Z':'z',
+					(vmState.sr&0x02)?'V':'v',
+					(vmState.sr&0x01)?'C':'c'
+			       );//cvznx
 			for (i=0;i<8;i++)
 			{
 				fprintf(stderr,"A%d=0x%08X  D%d=0x%08X\n",i,vmState.aregs[i],i,vmState.dregs[i]);
@@ -614,6 +674,7 @@ int main(int argc,char** argv)
 
 
 	} while (retval==DMAGNETIC_OK_RESTART);
+	free(picture);
 	free(hEngine);
 	free(gfxbuf);
 	free(magbuf);
