@@ -32,7 +32,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <stdlib.h>
 #include <string.h>
 #include "linea.h"
-#include "gfx1loader.h"
+#include "gfxloader.h"
 #include "vm68k_datatypes.h"
 #include "vm68k_macros.h"
 
@@ -48,7 +48,7 @@ typedef struct _tProperties
 	tVM68k_ubyte flags1;
 	tVM68k_ubyte flags2;
 	tVM68k_ubyte unknown2;
-	tVM68k_uword parentobject;	
+	tVM68k_uword parentobject;
 	tVM68k_ubyte unknown3[2];
 	tVM68k_uword endflags;
 } tProperties;
@@ -66,7 +66,7 @@ typedef struct _tLineA
 	tVM68k_ulong	string1size;	// the strings for some adventures were stored in two parts, since they have gotten too big
 	tVM68k_ulong	string2size;	// 
 	tVM68k_ubyte*	pDict;
-	tVM68k_ulong	dictsize;	
+	tVM68k_ulong	dictsize;
 	tVM68k_ulong	decsize;
 	tVM68k_ubyte*	pStringHuffman;
 	tVM68k_ubyte*	pUndo;
@@ -80,6 +80,7 @@ typedef struct _tLineA
 	void*			contextInputString;
 	cbLineADrawPicture	pcbDrawPicture;
 	void*			contextDrawPicture;
+	tdMagneticPicture* 	pPicture;
 	cbLineASaveGame		pcbSaveGame;
 	void*			contextSaveGame;
 	cbLineALoadGame		pcbLoadGame;
@@ -115,7 +116,7 @@ typedef struct _tLineA
 	unsigned char lastchar;
 	int jinxterslide;		// workaround for the sliding puzzle in Jinxter
 	char picname[16];		// name or number of the picture to be shown
-	
+
 
 	tVM68k_ubyte *magbuf;
 	tVM68k_ulong magsize;
@@ -127,9 +128,8 @@ typedef struct _tLineA
 
 	// dump the pictures as .xpm and quit
 	tVM68k_bool dumpxpm;
-	
 
-	tdMagneticPicture picture;
+
 } tLineA;
 
 
@@ -187,7 +187,7 @@ int lineA_parsegamefiles(tLineA* pLineA,void* pMag,int magsize,void* pGfx,int gf
 	// because the same section is writable. first: drain the memory.
 	memset(pLineA->pMem,0,pLineA->memsize);
 	if (pLineA->memsize<pLineA->codesize) return LINEA_NOK_NOT_ENOUGH_MEMORY;
-	
+
 	pLineA->memsize=pLineA->codesize;
 	if (pLineA->memsize<0x10000) pLineA->memsize=0x10000;	// miminum memory size
 
@@ -200,15 +200,20 @@ int lineA_parsegamefiles(tLineA* pLineA,void* pMag,int magsize,void* pGfx,int gf
 	// for conveniance reasons, i am adding the pointers.
 	pLineA->pStrings1=&pLineA->magbuf[idx];idx+=pLineA->string1size+pLineA->string2size;
 	pLineA->pDict=&pLineA->magbuf[idx];idx+=pLineA->dictsize;
-	pLineA->pUndo=&pLineA->magbuf[idx];idx+=pLineA->undosize;
+	pLineA->pUndo=&pLineA->magbuf[idx];//idx+=pLineA->undosize;
 	pLineA->pStringHuffman=&pLineA->pStrings1[pLineA->decsize];
-	
+
 	pLineA->gfxsize=gfxsize;
 	if (pGfx!=NULL)
 	{
 		pLineA->gfxbuf=(tVM68k_ubyte*)pGfx;
 	} 
-		
+	if (idx>magsize)
+	{
+		fprintf(stderr,"ERROR: .mag file broken? %d > %d\n",idx,magsize);
+		return LINEA_NOK;
+	}
+
 	return LINEA_OK;
 }
 int lineA_dumppics(void *hLineA)
@@ -226,11 +231,11 @@ int lineA_dumppics(void *hLineA)
 		for (i=0;i<30;i++)
 		{
 			snprintf(pLineA->picname,8,"%02d",i);
-			if (gfxloader_unpackpic(pLineA->gfxbuf,pLineA->gfxsize,pLineA->version,i,NULL,&(pLineA->picture),0)==LINEA_OK)
+			if (gfxloader_unpackpic(pLineA->gfxbuf,pLineA->gfxsize,pLineA->version,i,NULL,pLineA->pPicture,0)==LINEA_OK)
 			{
-				pLineA->pcbDrawPicture(pLineA->contextDrawPicture,&pLineA->picture,pLineA->picname,1);
+				pLineA->pcbDrawPicture(pLineA->contextDrawPicture,pLineA->pPicture,pLineA->picname,1);
 			}
-		}	
+		}
 	} else {
 		int dirsize;
 		int diridx;
@@ -252,16 +257,16 @@ int lineA_dumppics(void *hLineA)
 			pLineA->picname[0]='v'; pLineA->picname[1]='g'; pLineA->picname[2]='a';pLineA->picname[3]='_';
 			memcpy(&pLineA->picname[4],&(pLineA->gfxbuf[diridx]),6);
 			pLineA->picname[10]=0;
-			
-			if (gfxloader_unpackpic(pLineA->gfxbuf,pLineA->gfxsize,pLineA->version,-1,&pLineA->picname[4],&(pLineA->picture),0)==LINEA_OK)	// extract the VGA picture
+
+			if (gfxloader_unpackpic(pLineA->gfxbuf,pLineA->gfxsize,pLineA->version,-1,&pLineA->picname[4],pLineA->pPicture,0)==LINEA_OK)	// extract the VGA picture
 			{
 				pLineA->picname[0]='v';
-				pLineA->pcbDrawPicture(pLineA->contextDrawPicture,&pLineA->picture,pLineA->picname,2);
+				pLineA->pcbDrawPicture(pLineA->contextDrawPicture,pLineA->pPicture,pLineA->picname,2);
 			}
-			if (gfxloader_unpackpic(pLineA->gfxbuf,pLineA->gfxsize,pLineA->version,-1,&pLineA->picname[4],&(pLineA->picture),1)==LINEA_OK)	// extract the EGA picture
+			if (gfxloader_unpackpic(pLineA->gfxbuf,pLineA->gfxsize,pLineA->version,-1,&pLineA->picname[4],pLineA->pPicture,1)==LINEA_OK)	// extract the EGA picture
 			{
 				pLineA->picname[0]='e';
-				pLineA->pcbDrawPicture(pLineA->contextDrawPicture,&pLineA->picture,pLineA->picname,2);
+				pLineA->pcbDrawPicture(pLineA->contextDrawPicture,pLineA->pPicture,pLineA->picname,2);
 			}
 
 			dirsize-=entrysize;
@@ -304,7 +309,7 @@ int lineA_newchar(tLineA* pLineA,unsigned char c,unsigned char controlD2,unsigne
 	if (flag_headline && !pLineA->headlineflagged) 	// this starts a headline
 	{
 		lineA_flush(pLineA);	// make sure the output buffers are being flushed
-		pLineA->headline_writeidx=0;	
+		pLineA->headline_writeidx=0;
 	}
 	if (!flag_headline && pLineA->headlineflagged)	// after the headline ends, a new paragraph is beginning
 	{
@@ -312,7 +317,7 @@ int lineA_newchar(tLineA* pLineA,unsigned char c,unsigned char controlD2,unsigne
 		pLineA->capital=1;	// obviously, this starts with a capital letter
 		for (i=0;i<pLineA->headline_writeidx;i++)
 		{
-			if (pLineA->headlinebuf[i]==0x0a)
+			if (pLineA->headlinebuf[i]<' ')
 			{
 				pLineA->headlinebuf[i]=0;
 				pLineA->headline_writeidx--;
@@ -353,7 +358,7 @@ int lineA_newchar(tLineA* pLineA,unsigned char c,unsigned char controlD2,unsigne
 			}
 			if (c2=='.' || c2=='!' || c2==':' || c2=='?')	// a sentence is ending.
 			{
-				pLineA->capital=1;	
+				pLineA->capital=1;
 			}
 			if (((c2>='a' && c2<='z') || (c2>='A' && c2<='Z')) && (pLineA->capital||flag_headline)) 	// the first letter must be written as uppercase. As well as the headline.
 			{
@@ -379,17 +384,24 @@ int lineA_newchar(tLineA* pLineA,unsigned char c,unsigned char controlD2,unsigne
 			}
 			if (pLineA->textbuf_writeidx>0 && pLineA->lastchar==' ' && (c2==',' || c2==';' || c2=='.' || c2=='!'))	// there have been some glitches with extra spaces, right before a komma. which , as you can see , looks weird.
 			{
-				pLineA->textbuf_writeidx--;	
+				pLineA->textbuf_writeidx--;
 			}
 			if (	//allow multiple spaces in certain scenarios
 					flag_headline || pLineA->lastchar!=' ' || c2!=' ')	// combine multiple spaces into a single one.
-			{	
+			{
 				if (c2==0x0a || (c2>=32 && c2<127 && c2!='@')) 
 				{
 					if (flag_headline) 
 					{
 						if (pLineA->headline_writeidx<MAXHEADLINEBUFFER-1)
-							pLineA->headlinebuf[pLineA->headline_writeidx++]=c2&0x7f;
+						{
+							if ((c2&0x7f)>=' ')
+							{
+								pLineA->headlinebuf[pLineA->headline_writeidx++]=c2&0x7f;
+							} else {
+								pLineA->headlinebuf[pLineA->headline_writeidx++]=0;
+							}
+						}
 					} else if (pLineA->textbuf_writeidx<MAXTEXTBUFFER-1) {
 						if (pLineA->textbuf_writeidx<MAXTEXTBUFFER-1)
 						{
@@ -430,14 +442,14 @@ int lineA_showTitleScreen(void* hLineA)
 	if (hLineA==NULL) return LINEA_NOK_INVALID_PTR;
 	// the pc version has title screens. it would be a shame not to show them.
 	if (pLineA->gfxsize) {
-		if (pLineA->gfxbuf[0]=='M' && pLineA->gfxbuf[1]=='a' && pLineA->gfxbuf[2]=='P' && pLineA->gfxbuf[3]=='3')	
-		{	
+		if (pLineA->gfxbuf[0]=='M' && pLineA->gfxbuf[1]=='a' && pLineA->gfxbuf[2]=='P' && pLineA->gfxbuf[3]=='3')
+		{
 			int i;
 			char string[]="Press Enter\n";
-			gfxloader_unpackpic(pLineA->gfxbuf,pLineA->gfxsize,pLineA->version,30,NULL,&pLineA->picture,0);
+			gfxloader_unpackpic(pLineA->gfxbuf,pLineA->gfxsize,pLineA->version,30,NULL,pLineA->pPicture,0);
 			if (pLineA->pcbDrawPicture!=NULL)
 			{
-				pLineA->pcbDrawPicture(pLineA->contextDrawPicture,&pLineA->picture,"30",1);
+				pLineA->pcbDrawPicture(pLineA->contextDrawPicture,pLineA->pPicture,"30",1);
 
 			}
 			for (i=0;i<strlen(string);i++)
@@ -474,11 +486,11 @@ int lineA_loadproperties(tLineA* pLineA,tVM68k* pVM68k,tVM68k_uword objectnum,tV
 		objectnum=READ_INT16BE(pVM68k->memory,addr);
 	}
 	addr=pLineA->properties_offset+14*objectnum;
-	
+
 	for (i=0;i<5;i++)
 	{
 		pProperties->unknown1[i]=pVM68k->memory[addr+i];
-	}	
+	}
 	pProperties->flags1=pVM68k->memory[addr+5];
 	pProperties->flags2=pVM68k->memory[addr+6];
 	pProperties->unknown2=pVM68k->memory[addr+7];
@@ -489,7 +501,7 @@ int lineA_loadproperties(tLineA* pLineA,tVM68k* pVM68k,tVM68k_uword objectnum,tV
 	}
 	pProperties->endflags=READ_INT16BE(pVM68k->memory,addr+12);
 	if (retaddr!=NULL) *retaddr=addr;
-	return LINEA_OK;	
+	return LINEA_OK;
 }
 int lineA_substitute_aliases(void* hLineA,unsigned short* opcode)
 {
@@ -515,17 +527,17 @@ int lineA_init(void* hLineA,void* pSharedMem,int sharedmemsize,void* pMag,int ma
 	pLineA->random_mode=0;
 	pLineA->random_state=12345;
 
-	pLineA->pMem=pSharedMem;			
+	pLineA->pMem=pSharedMem;
 	pLineA->memsize=sharedmemsize;
 
 	pLineA->pcbNewOutput=NULL;	pLineA->contextNewOutput=NULL;
 	pLineA->pcbInputString=NULL;	pLineA->contextInputString=NULL;
-	pLineA->pcbDrawPicture=NULL;	pLineA->contextDrawPicture=NULL;
+	pLineA->pcbDrawPicture=NULL;	pLineA->contextDrawPicture=NULL;pLineA->pPicture=NULL;
 	pLineA->pcbSaveGame=NULL;	pLineA->contextSaveGame=NULL;
 	pLineA->pcbLoadGame=NULL;	pLineA->contextLoadGame=NULL;
-	
+
 	retval=lineA_parsegamefiles(pLineA,pMag,magsize,pGfx,gfxsize);
-	
+
 	return retval;
 }
 int lineA_configrandom(void* hLineA,char random_mode,unsigned int random_seed)
@@ -605,7 +617,7 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 				}
 				idx=(opcode|0x0800);
 				idx^=0xffff;
-				base=READ_INT16BE(pVM68k->memory,(pLineA->linef_tab+2*idx));	
+				base=READ_INT16BE(pVM68k->memory,(pLineA->linef_tab+2*idx));
 				pVM68k->pcr=(pLineA->linef_tab+2*idx+base)%pVM68k->memsize;	// jump, then jump again.
 			} else {
 				// push long to stack
@@ -613,7 +625,7 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 				WRITE_INT32BE(pVM68k->memory,pVM68k->a[7],pVM68k->pcr);
 				pVM68k->pcr=(pLineA->linef_subroutine)%pVM68k->memsize;
 			}
-			
+
 		}
 		return LINEA_OK;
 	}
@@ -639,7 +651,7 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 					pLineA->level=0;
 					pLineA->used=0;
 
-					
+
 					if (pLineA->pcbInputString!=NULL)
 					{
 						pLineA->pcbInputString(pLineA->contextInputString,&pLineA->level,pLineA->inputbuf);	// callback to fill the input buffer.
@@ -658,7 +670,7 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 		case 0xa0de:	// version 3 (corruption) introduced this. the other implementation wrote a 1 into D1.
 			{
 				pVM68k->d[1]&=0xffffff00;
-				pVM68k->d[1]|=0x01;	
+				pVM68k->d[1]|=0x01;
 			}
 			break;
 		case 0xa0df:	// version 3 (corruption) introduced this.
@@ -679,8 +691,8 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 					case 7:	// show picture
 						if (pLineA->gfxsize && pLineA->pcbDrawPicture!=NULL)
 						{
-							gfxloader_unpackpic(pLineA->gfxbuf,pLineA->gfxsize,pLineA->version,-1,pLineA->picname,&pLineA->picture,pLineA->egamode);
-							pLineA->pcbDrawPicture(pLineA->contextDrawPicture,&pLineA->picture,pLineA->picname,2);
+							gfxloader_unpackpic(pLineA->gfxbuf,pLineA->gfxsize,pLineA->version,-1,pLineA->picname,pLineA->pPicture,pLineA->egamode);
+							pLineA->pcbDrawPicture(pLineA->contextDrawPicture,pLineA->pPicture,pLineA->picname,2);
 
 						}
 						lineA_flush(pLineA);	// report the new picture
@@ -690,7 +702,7 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 				}
 			}
 			break;
-		case 0xa0e0:	// unknown
+		case 0xa0e0:	// unknown, PROMPT_EV
 			break;
 		case 0xa0e1:	// getstring, new feature by corruption! (version4)
 			{
@@ -735,7 +747,7 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 				pVM68k->d[1]&=0xffff0000;
 				if (i==MAXINPUTBUFFER || i==1)
 				{
-					pVM68k->d[1]|=1;	
+					pVM68k->d[1]|=1;
 				}
 			}
 			break;
@@ -749,7 +761,7 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 				}
 			}
 			break;
-		case 0xa0e4:	
+		case 0xa0e4:
 			{
 					pVM68k->a[7]+=4;	// increase the stack pointer? maybe skip an entry or something?
 					pVM68k->pcr=READ_INT32BE(pVM68k->memory,pVM68k->a[7])%pVM68k->memsize;
@@ -792,7 +804,7 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 				unsigned char c;
 				tVM68k_ubyte*	dictptr;
 				tVM68k_uword	dictidx;
-					
+
 				if (pLineA->pDict==NULL || pLineA->dictsize==0) 
 				{
 					retval=LINEA_NOK_INVALID_PTR;
@@ -845,8 +857,8 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 				{
 					if (pLineA->gfxsize && pLineA->pcbDrawPicture!=NULL)
 					{
-						gfxloader_unpackpic(pLineA->gfxbuf,pLineA->gfxsize,pLineA->version,picnum,NULL,&pLineA->picture,pLineA->egamode);
-						pLineA->pcbDrawPicture(pLineA->contextDrawPicture,&pLineA->picture,pLineA->picname,picmode);
+						gfxloader_unpackpic(pLineA->gfxbuf,pLineA->gfxsize,pLineA->version,picnum,NULL,pLineA->pPicture,pLineA->egamode);
+						pLineA->pcbDrawPicture(pLineA->contextDrawPicture,pLineA->pPicture,pLineA->picname,picmode);
 					}
 					lineA_flush(pLineA);	// report the new picture
 				}
@@ -883,7 +895,7 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 				pVM68k->d[0]|=pVM68k->d[2]&0xffff;
 				found=0;
 				retval=lineA_loadproperties(pLineA,pVM68k,objectnum,&pVM68k->a[0],&properties);
-				do	
+				do
 				{
 					if (properties.endflags&0x3fff) 
 					{
@@ -911,7 +923,7 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 						&pVM68k->memory[(pVM68k->a[1]&0xffff)],	// ptr
 						(pVM68k->d[1]&0xffff)	// len
 					);
-				}	
+				}
 			}
 			break;
 		case 0xa0f5:
@@ -970,7 +982,6 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 				char c;
 				if (!(pVM68k->sr&(1<<0)))	// cflag is in bit 0.
 				{
-					byteidx=0;	// start the byteidx and bitidx counter
 					bitidx=0;
 					idx=pVM68k->d[0]&0xffff;
 					if (idx==0) byteidx=idx;
@@ -978,7 +989,7 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 					// the decoder table is 256 bytes long. afterwards, a bunch of pointers
 					// to bit indexes follow.
 					else byteidx=READ_INT16BE(pLineA->pStringHuffman,(0x100+2*idx));
-					tmp=READ_INT16BE(pLineA->pStringHuffman,0x100);	
+					tmp=READ_INT16BE(pLineA->pStringHuffman,0x100);
 					if (tmp && idx>=tmp)
 					{
 						byteidx+=pLineA->string1size;
@@ -1011,23 +1022,23 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 						}
 					}
 					val&=0x7f;	// remove bit 7.
-					c=val;	
+					c=val;
 
 
 					lineA_newchar(pLineA,c,pVM68k->d[2]&0xff,pVM68k->d[3]&0xff);
-			
+
 				}
 				while (val!=0 && !(prevval==' ' && val=='@'));	// end markers for the string are \0 and " @"
 				if (prevval==' ' && val=='@')		// extend the string next time this function is being called.
 				{
-					pVM68k->sr|=(1<<0);	// set the cflag. cflag=bit 0.	
+					pVM68k->sr|=(1<<0);	// set the cflag. cflag=bit 0.
 					pLineA->interrupted_byteidx=byteidx;
 					pLineA->interrupted_bitidx=bitidx;
 				} else {
-					pVM68k->sr&=~(1<<0);	// clear the cflag. cflag=bit 0.	
+					pVM68k->sr&=~(1<<0);	// clear the cflag. cflag=bit 0.
 				}
 
-				
+
 			}
 			break;
 		case 0xa0f9:	//get inventory item(d0)
@@ -1071,7 +1082,7 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 						{
 							objectnum2=0;	// break the loop
 						}
-					} while (objectnum2);	
+					} while (objectnum2);
 				}
 				// set the z-flag when the object was found. otherwise clear it.
 				pVM68k->sr&=~(1<<2);	// zflag is bit 2
@@ -1094,12 +1105,12 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 				tVM68k_uword pattern;
 				tVM68k_uword value;
 				tVM68k_bool byte0word1;
-	
+
 				found=0;
 				addr=pVM68k->a[0];
 				pattern=pVM68k->d[2];
 				byte0word1=pVM68k->d[5];
-				pVM68k->sr&=~(1<<0);	// cflag is bit 0;	
+				pVM68k->sr&=~(1<<0);	// cflag is bit 0;
 				for (i=(pVM68k->d[3]&0xffff);i<(pVM68k->d[4]&0xffff) && !found;i++)
 				{
 					if (byte0word1)
@@ -1119,17 +1130,17 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 					}
 				}
 				pVM68k->d[3]=i;
-				
+
 			}
 			break;
 		case 0xa0fb:
-           		{	// skip D2 many words in the dictionary, that is pointed at by A1
+			{	// skip D2 many words in the dictionary, that is pointed at by A1
 				tVM68k_ubyte*	dictptr;
 				tVM68k_uword	dictidx;
 				tVM68k_ubyte	cdict;
 				int i;
 				int n;
-				
+
 
 				dictidx=0;
 				if (pLineA->version==0 || pLineA->pDict==NULL || pLineA->dictsize==0) 
@@ -1167,10 +1178,10 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 					dictptr=&pLineA->pDict[pVM68k->a[0]&0xffff];
 				}
 				inputptr=&pVM68k->memory[pVM68k->a[1]&0xffff];
-				n=(pVM68k->d[0])&0xffff;	
+				n=(pVM68k->d[0])&0xffff;
 				for (i=0;i<n;i++)
 				{
-					tVM68k_ubyte cdebug;	
+					tVM68k_ubyte cdebug;
 					do
 					{
 						cdebug=dictptr[dictidx++];
@@ -1202,7 +1213,7 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 					if (pLineA->version>2)
 					{
 						pLineA->properties_tab=(pVM68k->a[6])&0xffff;
-						pLineA->properties_size=(pVM68k->d[6]);	
+						pLineA->properties_size=(pVM68k->d[6]);
 					}
 				}
 				break;
@@ -1211,10 +1222,10 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 					// register D0 conatins an object number. calculate the address in memory
 					tVM68k_sword objectnum;
 					tVM68k_ulong objectidx;
-					
+
 					if (pLineA->version>2 && (pVM68k->d[0]&0x3fff)>pLineA->properties_size)
 					{
-						pVM68k->d[0]&=0xffff7fff;	
+						pVM68k->d[0]&=0xffff7fff;
 //						objectidx=((pLineA->properties_size-(pVM68k->d[0]&0x3fff))^0xffff);	// TODO: I THINK THIS IS JUST A MODULO!!!
 						objectidx=((pVM68k->d[0]&0x3fff)-pLineA->properties_size)-1;
 						objectnum=READ_INT16BE(pVM68k->memory,pLineA->properties_tab+objectidx*2);
@@ -1248,7 +1259,7 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 					// output: (A2)
 					// dict: (A3)
 					// objects: (A1)
-					
+
 					{
 						tVM68k_ubyte* dtabptr;
 						tVM68k_ubyte* inputptr;
@@ -1261,22 +1272,20 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 						tVM68k_uword	outputidx;
 						tVM68k_uword	outputidx2;
 						tVM68k_uword	dictidx;
-						tVM68k_uword	objectidx;
 						tVM68k_uword	adjidx;
-	
+
 						tVM68k_uword	wordidx;
 						tVM68k_ubyte	bank;
 						tVM68k_ubyte	flag;
 						tVM68k_bool	matching;
-	
-						tVM68k_ubyte	cinput1,cinput2;
+
 						tVM68k_ubyte	cdict;
 						tVM68k_bool	matchfound;
 						tVM68k_ulong	wordmatch;
 						tVM68k_uword	longestmatch;
-	
+
 						tVM68k_ubyte	flag2;
-							
+
 						int i,j;
 						longestmatch=0;
 						flag2=0;
@@ -1289,21 +1298,20 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 						} else {
 							dictptr=&pLineA->pDict[pVM68k->a[3]&0xffff];
 							dtabptr=&pLineA->pDict[pVM68k->a[5]&0xffff];	// version>0
-							
+
 						}
 						outputptr =&pVM68k->memory[pVM68k->a[2]];
 						objectptr =&pVM68k->memory[pVM68k->a[1]];
 						adjptr    =&pVM68k->memory[pVM68k->a[0]];
-						inputidx=dictidx=objectidx=outputidx=adjidx=0;
+						inputidx=dictidx=outputidx=0;
 						pVM68k->d[0]&=0xffff0000;		// this regsiter was used during the adjective search.
 						pVM68k->d[1]&=0xffff0000;		// this regsiter was used during the adjective search.
-				
+
 						flag=0;
 						bank=(pVM68k->d[6]&0xff);
 						wordidx=0;
 						cdict=0;
 						matching=1;
-						cinput1=cinput2=0;
 						matchfound=0;
 						pVM68k->d[0]&=0xffff0000;
 						// the way the first loop works is this:
@@ -1321,6 +1329,7 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 								bank++;
 								matching=1;
 							} else if (matching) {	// actively comparing
+								tVM68k_ubyte	cinput1,cinput2;
 								cinput1=inputptr[inputidx++];	// the current character
 								cinput2=inputptr[inputidx];	// and the next onea
 								if (pLineA->version!=0)
@@ -1330,7 +1339,7 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 										flag=0x80;	// the dictionary uses _ to signal objects that consist of longer words. "can of worms" thus becomes "can_of_worms". the matcher has to find it.
 										cinput1='_';	// replace the space from the input with an _ to see if there is a match.
 									}
-									
+
 								}
 								if (cdict&0x80)	// the end of an entry in the dictionary is marked by bit 7 being set.
 								{
@@ -1359,12 +1368,12 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 									{
 										if (cinput1==' ' && cdict==0x5f) // multiple word entry found
 										{
-											flag=1;		
+											flag=1;
 											cinput1=0x5f;	// multiple word entries are marked by a _ instead of a space. this one makes sure that the next if() will work.
 										}
 									}
 									if ((cinput1&0x5f)!=(cdict&0x5f) 
-										|| (cdict&0x5f)==0x00 	// FIXME	
+										|| (cdict&0x5f)==0x00 	// FIXME
 									)
 									{
 										if (cinput2==' ' && pLineA->version==0 && inputidx>=7) matchfound=1;	// the first 7 characters matched. good enough.
@@ -1394,7 +1403,7 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 								flag=0;
 							}
 						}
-	
+
 						WRITE_INT16BE(outputptr,outputidx,0xffff);// the end marker in the buffer is a 0xffff.
 						// the output buffer holds outputidx/4 many results.
 						if (pLineA->version!=0)	// version 1 introduced synonyms.
@@ -1410,7 +1419,7 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 								{
 									tVM68k_uword substword;
 									substword=READ_INT16BE(dtabptr,wordidx*2);		// TODO: version >1???
-		
+
 									// the lower 5 bits are the bank.
 									// the upper 11 bits in the substitute database are the actual word index.
 									bank=substword&0x1f;
@@ -1419,7 +1428,7 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 									wordmatch|=(bank&0xff);wordmatch<<=16;
 									wordmatch|=wordidx&0xffff;
 									WRITE_INT32BE(outputptr,i,wordmatch);
-							
+
 								}
 
 							} 
@@ -1429,6 +1438,7 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 						adjidx=0;
 						for (i=0;i<outputidx;i+=4)
 						{
+							tVM68k_uword	objectidx;
 							tVM68k_uword	adjidx_base;
 							tVM68k_uword	obj;
 							tVM68k_bool	mismatch;
@@ -1437,8 +1447,8 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 							flag=(wordmatch>>24)&0xff;
 							bank=(wordmatch>>16)&0xff;
 							wordidx=wordmatch&0xffff;
-						
-							mismatch=0;	
+
+							mismatch=0;
 							obj=READ_INT16BE(objectptr,objectidx);
 							if (obj && bank==6)
 							{
@@ -1473,6 +1483,7 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 								*/
 								do
 								{
+									tVM68k_ubyte cinput2;
 									adjidx=adjidx_base;
 									cinput2=READ_INT8BE(objectptr,objectidx+1);
 									obj=READ_INT16BE(objectptr,objectidx);
@@ -1486,13 +1497,13 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 										} while (cdict && ((cdict-3)!=cinput2));
 										//if ((cdict-3)==cinput2)	printf("MATCH!\n");
 										if ((cdict-3)!=cinput2) mismatch=1;
-										
+
 									}
 								}
 								while (obj && !mismatch);
 								adjidx=0;
 							}
-							
+
 							pVM68k->d[1]&=0xffff0000;
 							if (mismatch==0) 
 							{
@@ -1503,7 +1514,7 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 								WRITE_INT32BE(outputptr,outputidx2,wordmatch);
 								outputidx2+=4;
 							} else {
-								
+
 								pVM68k->d[1]|=1;
 							}
 						}
@@ -1513,7 +1524,7 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 						{
 							for (i=0;i<outputidx && flag2;i+=4)
 							{
-								
+
 								wordmatch=READ_INT32BE(outputptr,i);	// find the wordmatch with the flag set.
 								if (wordmatch&0x80000000)
 								{
@@ -1527,7 +1538,7 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 							{
 								pVM68k->a[5]=pVM68k->a[6]+(longestmatch-3);
 							}
-								
+
 						}
 						pVM68k->a[2]+=outputidx2;
 //						pVM68k->d[0]=0;
@@ -1541,7 +1552,7 @@ int lineA_singlestep(void* hLineA,void* hVM68k,unsigned short opcode)
 				break;
 	}
 
-	return retval;	
+	return retval;
 }
 
 int lineA_setCBnewOutput(void* hLineA,cbLineANewOutput pCB,void* context)
@@ -1570,7 +1581,7 @@ int lineA_setCBinputString(void* hLineA,cbLineAInputString pCB,void* context)
 }
 
 
-int lineA_setCBdrawPicture(void* hLineA,cbLineADrawPicture pCB,void* context)
+int lineA_setCBdrawPicture(void* hLineA,cbLineADrawPicture pCB,void* context,tdMagneticPicture *pPicture)
 {
 	tLineA* pLineA=(tLineA*)hLineA;
 	if (pLineA==NULL) return LINEA_NOK_INVALID_PTR;
@@ -1578,6 +1589,7 @@ int lineA_setCBdrawPicture(void* hLineA,cbLineADrawPicture pCB,void* context)
 
 	pLineA->pcbDrawPicture=pCB;
 	pLineA->contextDrawPicture=context;
+	pLineA->pPicture=pPicture;
 
 	return LINEA_OK;
 
