@@ -39,64 +39,64 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 tVM68k_bool vm68k_checkcondition(tVM68k* pVM68k,tVM68k_ubyte condition)
 {               
-	#define	CFLAG(pVM68k)	((((pVM68k)->sr)>>0)&1)
-	#define	VFLAG(pVM68k)	((((pVM68k)->sr)>>1)&1)
-	#define	ZFLAG(pVM68k)	((((pVM68k)->sr)>>2)&1)
-	#define	NFLAG(pVM68k)	((((pVM68k)->sr)>>3)&1)
-	#define	XFLAG(pVM68k)	((((pVM68k)->sr)>>4)&1)
+#define	CFLAG(pVM68k)	((((pVM68k)->sr)>>0)&1)
+#define	VFLAG(pVM68k)	((((pVM68k)->sr)>>1)&1)
+#define	ZFLAG(pVM68k)	((((pVM68k)->sr)>>2)&1)
+#define	NFLAG(pVM68k)	((((pVM68k)->sr)>>3)&1)
+#define	XFLAG(pVM68k)	((((pVM68k)->sr)>>4)&1)
 
-        tVM68k_bool     condtrue;
-        switch(condition)
-        {
-                case  0: condtrue=1;break;
-                case  1: condtrue=0;break;
-                case  2: //BHI high 0010 /C | /Z
-                         condtrue=!(CFLAG(pVM68k)|ZFLAG(pVM68k));
-                         break; 
-                case  3: //LS low or same 0011 C & Z
-                         condtrue= (CFLAG(pVM68k)|ZFLAG(pVM68k));
-                         break; 
-                case  4://BCC carry clear 0100 /C
-                         condtrue=!(CFLAG(pVM68k)); 
-                         break; 
-                case  5://BCS carry set 0101 C
-                         condtrue= (CFLAG(pVM68k));
-                         break;
-                case  6://BNE not equal 0110 /Z
-                         condtrue=!(ZFLAG(pVM68k));
-                         break;
-                case  7://BEQ equal 0111 Z
-                         condtrue= (ZFLAG(pVM68k));
-                         break;
-                case  8://BVC overflow clear 1000 /V
-                         condtrue=!(VFLAG(pVM68k));
-                         break;
-                case  9://BVS overflow set 1001 V 
-                         condtrue= (VFLAG(pVM68k));
-                         break;
-                case 10://BPL plus 1010 /N
-                         condtrue=!(NFLAG(pVM68k));
-                         break;
-                case 11://BMI minus 1011 N
-                         condtrue= (NFLAG(pVM68k));
-                         break;
-                case 12://BGE greater or equal 1100 (N & V) | (/N & /V), N and V are both set or both clear
-                         condtrue=!((NFLAG(pVM68k)^VFLAG(pVM68k)));
-                         break;
-                case 13://BLT less than  1101 (N & /V) | (/N & V), N and V are either set or clear
-                         condtrue= ((NFLAG(pVM68k)^VFLAG(pVM68k)));
-                         break;
-                case 14://BGT greater than 1110 (N & V & /Z) | (/N & /V & /Z)
-                         condtrue=!ZFLAG(pVM68k)&!((NFLAG(pVM68k)^VFLAG(pVM68k)));
-                         break;
-                case 15://BLE less or equal 1111 
-                         condtrue=ZFLAG(pVM68k)|((NFLAG(pVM68k)^VFLAG(pVM68k)));
-                         break;
-                default:
-                         condtrue=0;
-                         break;
-        }
-        return condtrue;
+	tVM68k_bool     condtrue;
+	switch(condition)
+	{
+		case  0: condtrue=1;break;
+		case  1: condtrue=0;break;
+		case  2: //BHI high 0010 /C | /Z
+			 condtrue=!(CFLAG(pVM68k)|ZFLAG(pVM68k));
+			 break; 
+		case  3: //LS low or same 0011 C & Z
+			 condtrue= (CFLAG(pVM68k)|ZFLAG(pVM68k));
+			 break; 
+		case  4://BCC carry clear 0100 /C
+			 condtrue=!(CFLAG(pVM68k)); 
+			 break; 
+		case  5://BCS carry set 0101 C
+			 condtrue= (CFLAG(pVM68k));
+			 break;
+		case  6://BNE not equal 0110 /Z
+			 condtrue=!(ZFLAG(pVM68k));
+			 break;
+		case  7://BEQ equal 0111 Z
+			 condtrue= (ZFLAG(pVM68k));
+			 break;
+		case  8://BVC overflow clear 1000 /V
+			 condtrue=!(VFLAG(pVM68k));
+			 break;
+		case  9://BVS overflow set 1001 V 
+			 condtrue= (VFLAG(pVM68k));
+			 break;
+		case 10://BPL plus 1010 /N
+			 condtrue=!(NFLAG(pVM68k));
+			 break;
+		case 11://BMI minus 1011 N
+			 condtrue= (NFLAG(pVM68k));
+			 break;
+		case 12://BGE greater or equal 1100 (N & V) | (/N & /V), N and V are both set or both clear
+			 condtrue=!((NFLAG(pVM68k)^VFLAG(pVM68k)));
+			 break;
+		case 13://BLT less than  1101 (N & /V) | (/N & V), N and V are either set or clear
+			 condtrue= ((NFLAG(pVM68k)^VFLAG(pVM68k)));
+			 break;
+		case 14://BGT greater than 1110 (N & V & /Z) | (/N & /V & /Z)
+			 condtrue=!ZFLAG(pVM68k)&!((NFLAG(pVM68k)^VFLAG(pVM68k)));
+			 break;
+		case 15://BLE less or equal 1111 
+			 condtrue=ZFLAG(pVM68k)|((NFLAG(pVM68k)^VFLAG(pVM68k)));
+			 break;
+		default:
+			 condtrue=0;
+			 break;
+	}
+	return condtrue;
 }
 
 
@@ -105,7 +105,7 @@ tVM68k_bool vm68k_checkcondition(tVM68k* pVM68k,tVM68k_ubyte condition)
 int vm68k_getsize(int* size)
 {
 	if (size==NULL) return VM68K_NOK_INVALID_PTR;
-	
+
 	*size=sizeof(tVM68k);
 	return	VM68K_OK;
 }
@@ -123,7 +123,7 @@ int vm68k_init(void* hVM68k,int version)
 	pVM68k->version=version;
 
 	return	VM68K_OK;
-	
+
 }
 int vm68k_singlestep(void *hVM68k,unsigned short opcode)
 {
@@ -141,10 +141,10 @@ int vm68k_singlestep(void *hVM68k,unsigned short opcode)
 	tVM68k_ubyte		condition;
 	tVM68k_sword		displacement;
 	tVM68k_bool		direction;
-	
+
 	int retval;
 	int i;
-	
+
 	if (hVM68k==NULL) return VM68K_NOK_INVALID_PTR;
 	if (pVM68k->magic!=MAGICVALUE) return VM68K_NOK_INVALID_PARAMETER;
 
@@ -165,8 +165,9 @@ int vm68k_singlestep(void *hVM68k,unsigned short opcode)
 	// alu operations
 	direction=(opcode>>8)&0x1;
 
-	INITNEXT(pVM68k,next);	
+	INITNEXT(pVM68k,next);
 	result=0;
+	operand1=operand2=0;
 	switch(instruction)
 	{
 		case VM68K_INST_TRAP:
@@ -183,7 +184,7 @@ int vm68k_singlestep(void *hVM68k,unsigned short opcode)
 			if (retval==VM68K_OK) retval=vm68k_fetchoperand(pVM68k,0,VM68K_WORD,ea,&operand1);
 			if (retval==VM68K_OK) retval=vm68k_fetchoperand(pVM68k,0,VM68K_WORD,DATAREGADDR(reg1),&operand2);
 			if (retval==VM68K_OK) result=((unsigned int)operand1&0xffff)*((unsigned short)operand2&0xffff);
-			if (retval==VM68K_OK) retval=vm68k_calculateflags2(&next,FLAGS_ALL,instruction,VM68K_LONG,operand1,operand2,result);	
+			if (retval==VM68K_OK) retval=vm68k_calculateflags2(&next,FLAGS_ALL,instruction,VM68K_LONG,operand1,operand2,result);
 			if (retval==VM68K_OK) retval=vm68k_storeresult(pVM68k,&next,VM68K_LONG,DATAREGADDR(reg1),result);
 			break;
 		case VM68K_INST_DIVU:
@@ -192,10 +193,10 @@ int vm68k_singlestep(void *hVM68k,unsigned short opcode)
 			if (retval==VM68K_OK) retval=vm68k_fetchoperand(pVM68k,0,VM68K_WORD,ea,&operand1);
 			if (retval==VM68K_OK) retval=vm68k_fetchoperand(pVM68k,0,VM68K_WORD,DATAREGADDR(reg1),&operand2);
 			// upper 16 bits are the remainder
-			if (retval==VM68K_OK) result=(((unsigned int)operand1&0xffff)%((unsigned short)operand2&0xffff))<<16;	
+			if (retval==VM68K_OK) result=(((unsigned int)operand1&0xffff)%((unsigned short)operand2&0xffff))<<16;
 			// lower 16 bits are the quotient
 			if (retval==VM68K_OK) result|=(((unsigned int)operand1&0xffff)/((unsigned short)operand2&0xffff))&0xffff;
-			if (retval==VM68K_OK) retval=vm68k_calculateflags2(&next,FLAGS_ALL,instruction,VM68K_LONG,operand1,operand2,result);	
+			if (retval==VM68K_OK) retval=vm68k_calculateflags2(&next,FLAGS_ALL,instruction,VM68K_LONG,operand1,operand2,result);
 			if (retval==VM68K_OK) retval=vm68k_storeresult(pVM68k,&next,VM68K_LONG,DATAREGADDR(reg1),result);
 			break;
 		case VM68K_INST_ADD:
@@ -220,9 +221,9 @@ int vm68k_singlestep(void *hVM68k,unsigned short opcode)
 			} else {
 				result=operand2+operand1;
 			}
-			if (retval==VM68K_OK) retval=vm68k_calculateflags2(&next,FLAGS_ALL,instruction,datatype,operand1,operand2,result);	
+			if (retval==VM68K_OK) retval=vm68k_calculateflags2(&next,FLAGS_ALL,instruction,datatype,operand1,operand2,result);
 			if (retval==VM68K_OK && instruction!=VM68K_INST_CMP) retval=vm68k_storeresult(pVM68k,&next,datatype,(direction)?ea:DATAREGADDR(reg1),result);
-		break;
+			break;
 		case VM68K_INST_ADDA:
 		case VM68K_INST_CMPA:
 		case VM68K_INST_SUBA:
@@ -240,19 +241,19 @@ int vm68k_singlestep(void *hVM68k,unsigned short opcode)
 					datatype3=datatype2;
 				}
 				retval=vm68k_resolve_ea(pVM68k,&next,datatype2,addrmode,reg2,VM68K_LEGAL_ALL,&ea);
-				if (retval==VM68K_OK) retval=vm68k_fetchoperand(pVM68k,1,datatype2,ea,&operand2);
-				if (retval==VM68K_OK) retval=vm68k_fetchoperand(pVM68k,1,datatype3,ADDRREGADDR(reg1),&operand1);
-			
+				if (retval==VM68K_OK) retval=vm68k_fetchoperand(pVM68k,1,datatype2,ea,&operand1);
+				if (retval==VM68K_OK) retval=vm68k_fetchoperand(pVM68k,1,datatype3,ADDRREGADDR(reg1),&operand2);
+
 				if (instruction==VM68K_INST_SUBA || instruction==VM68K_INST_CMPA) 
 				{
-					result=operand1-operand2;
+					result=operand2-operand1;
 				} else {
 					result=operand2+operand1;
 				}
-				if (retval==VM68K_OK && instruction==VM68K_INST_CMPA) retval=vm68k_calculateflags2(&next,FLAGS_ALL,instruction,datatype2,operand1,operand2,result);	
+				if (retval==VM68K_OK && instruction==VM68K_INST_CMPA) retval=vm68k_calculateflags2(&next,FLAGS_ALL,instruction,datatype2,operand2,operand1,result);
 				if (retval==VM68K_OK && instruction!=VM68K_INST_CMPA) retval=vm68k_storeresult(pVM68k,&next,datatype3,ADDRREGADDR(reg1),result);
 			}
-		break;
+			break;
 		case VM68K_INST_ADDI:
 		case VM68K_INST_CMPI:
 		case VM68K_INST_SUBI:
@@ -273,61 +274,61 @@ int vm68k_singlestep(void *hVM68k,unsigned short opcode)
 			} else {
 				result=operand2+operand1;
 			}
-			if (retval==VM68K_OK) retval=vm68k_calculateflags2(&next,FLAGS_ALL,instruction,datatype,operand1,operand2,result);	
+			if (retval==VM68K_OK) retval=vm68k_calculateflags2(&next,FLAGS_ALL,instruction,datatype,operand1,operand2,result);
 			if (retval==VM68K_OK && instruction!=VM68K_INST_CMPI) retval=vm68k_storeresult(pVM68k,&next,datatype,ea,result);
-		break;
+			break;
 		case VM68K_INST_ADDQ:
 		case VM68K_INST_SUBQ:
-		{
-			tVM68k_sbyte quick;
-			tVM68k_bool version3_workaround;
-			retval=vm68k_resolve_ea(pVM68k,&next,datatype,addrmode,reg2,VM68K_LEGAL_ALTERABLEADRESSING,&ea);
-			if (retval==VM68K_OK) retval=vm68k_fetchoperand(pVM68k,1,datatype,ea,&operand2);
-			quick=reg1;
-			operand1=quick;
-			if (operand1==0) operand1=8;
-			if (instruction==VM68K_INST_SUBQ) 
 			{
-				result=operand2-operand1;
-			} else {
-				result=operand2+operand1;
+				tVM68k_sbyte quick;
+				tVM68k_bool version3_workaround;
+				retval=vm68k_resolve_ea(pVM68k,&next,datatype,addrmode,reg2,VM68K_LEGAL_ALTERABLEADRESSING,&ea);
+				if (retval==VM68K_OK) retval=vm68k_fetchoperand(pVM68k,1,datatype,ea,&operand2);
+				quick=reg1;
+				operand1=quick;
+				if (operand1==0) operand1=8;
+				if (instruction==VM68K_INST_SUBQ) 
+				{
+					result=operand2-operand1;
+				} else {
+					result=operand2+operand1;
+				}
+				version3_workaround=next.zflag;		// starting with version 3, the z-flag needed to be preserved. this was an inconsistency in the original engine, that just stuck.
+				if (retval==VM68K_OK) retval=vm68k_calculateflags2(&next,FLAGS_ALL,instruction,datatype,operand1,operand2,result);
+				if ((pVM68k->version>=3)  && (instruction==VM68K_INST_ADDQ)) next.zflag=version3_workaround;
+				if (retval==VM68K_OK && instruction!=VM68K_INST_CMPI) retval=vm68k_storeresult(pVM68k,&next,datatype,ea,result);
 			}
-			version3_workaround=next.zflag;		// starting with version 3, the z-flag needed to be preserved. this was an inconsistency in the original engine, that just stuck.
-			if (retval==VM68K_OK) retval=vm68k_calculateflags2(&next,FLAGS_ALL,instruction,datatype,operand1,operand2,result);	
-			if ((pVM68k->version>=3)  && (instruction==VM68K_INST_ADDQ)) next.zflag=version3_workaround;	
-			if (retval==VM68K_OK && instruction!=VM68K_INST_CMPI) retval=vm68k_storeresult(pVM68k,&next,datatype,ea,result);
-		}
-		break;
+			break;
 		case VM68K_INST_EXG:
-		{
-			tVM68k_sbyte	opmode;
-			opmode=(opcode>>3)&0x1f;
-			switch(opmode)
 			{
-				case 0x08:	next.d[reg1]=pVM68k->d[reg2];
-						next.d[reg2]=pVM68k->d[reg1];break;	// 01000= data registers.
-				case 0x09:	next.a[reg1]=pVM68k->a[reg2];
-						next.a[reg2]=pVM68k->a[reg1];break;	// 01001= addr registers.
-				case 0x11:	next.d[reg1]=pVM68k->a[reg2];
-						next.a[reg2]=pVM68k->d[reg1];break;	// 10001= data +addr registers.
+				tVM68k_sbyte	opmode;
+				opmode=(opcode>>3)&0x1f;
+				switch(opmode)
+				{
+					case 0x08:	next.d[reg1]=pVM68k->d[reg2];
+							next.d[reg2]=pVM68k->d[reg1];break;	// 01000= data registers.
+					case 0x09:	next.a[reg1]=pVM68k->a[reg2];
+							next.a[reg2]=pVM68k->a[reg1];break;	// 01001= addr registers.
+					case 0x11:	next.d[reg1]=pVM68k->a[reg2];
+							next.a[reg2]=pVM68k->d[reg1];break;	// 10001= data +addr registers.
+				}
+				retval=VM68K_OK;
 			}
-			retval=VM68K_OK;
-		}		
-		break;
+			break;
 		case VM68K_INST_MOVEQ:
-		{
-			tVM68k_types	datatype2;
-			tVM68k_sbyte data;
-			datatype2=VM68K_LONG;
+			{
+				tVM68k_types	datatype2;
+				tVM68k_sbyte data;
+				datatype2=VM68K_LONG;
+
+				data=opcode&0xff;
+				result=(tVM68k_slong)data;
+				retval=vm68k_calculateflags(&next,FLAGS_LOGIC,datatype2,0,0,result);
+				next.cflag=next.vflag=0;
+				if (retval==VM68K_OK) retval=vm68k_storeresult(pVM68k,&next,datatype2,DATAREGADDR(reg1),result);
+			}
+			break;
 
-			data=opcode&0xff;
-			result=(tVM68k_slong)data;
-			retval=vm68k_calculateflags(&next,FLAGS_LOGIC,datatype2,0,0,result);
-			next.cflag=next.vflag=0;
-			if (retval==VM68K_OK) retval=vm68k_storeresult(pVM68k,&next,datatype2,DATAREGADDR(reg1),result);
-		}
-		break;
-			
 
 		case VM68K_INST_AND:
 		case VM68K_INST_EOR:
@@ -350,10 +351,10 @@ int vm68k_singlestep(void *hVM68k,unsigned short opcode)
 				case VM68K_INST_EOR:	result=operand1^operand2;break;
 				case VM68K_INST_OR:	result=operand1|operand2;break;
 				default: retval=VM68K_NOK_UNKNOWN_INSTRUCTION;break;
-			}	
+			}
 			if (retval==VM68K_OK) retval=vm68k_calculateflags(&next,FLAGS_LOGIC,datatype,operand1,operand2,result);
 			if (retval==VM68K_OK) retval=vm68k_storeresult(pVM68k,&next,datatype,(direction)?ea:DATAREGADDR(reg1),result);
-		break;
+			break;
 		case VM68K_INST_ANDI:
 		case VM68K_INST_EORI:
 		case VM68K_INST_ORI:
@@ -370,7 +371,7 @@ int vm68k_singlestep(void *hVM68k,unsigned short opcode)
 			if (retval==VM68K_OK) retval=vm68k_calculateflags(&next,FLAGS_LOGIC,datatype,operand1,operand2,result);
 			if (retval==VM68K_OK) retval=vm68k_storeresult(pVM68k,&next,datatype,ea,result);
 
-		break;
+			break;
 		case VM68K_INST_BCC:
 			if (displacement==0) 
 			{
@@ -382,80 +383,80 @@ int vm68k_singlestep(void *hVM68k,unsigned short opcode)
 			}
 			if (vm68k_checkcondition(pVM68k,condition) || condition==1)
 			{
-				next.pcr=pVM68k->pcr+displacement;		
+				next.pcr=pVM68k->pcr+displacement;
 			}
 			retval=VM68K_OK;
-		break;
+			break;
 		case VM68K_INST_MOVE:
 		case VM68K_INST_MOVEA:
-		{
-			tVM68k_types	datatype2;
-			tVM68k_ubyte	addrmode_dest;
-			tVM68k_slong	ea_dest;
-			datatype2=VM68K_UNKNOWN;
-			retval=VM68K_OK;
-			switch ((opcode>>12)&0x3)
 			{
-				case 1: datatype2=VM68K_BYTE;break;
-				case 3: datatype2=VM68K_WORD;break;
-				case 2: datatype2=VM68K_LONG;break;
-				default: retval=VM68K_NOK_UNKNOWN_INSTRUCTION;
+				tVM68k_types	datatype2;
+				tVM68k_ubyte	addrmode_dest;
+				tVM68k_slong	ea_dest;
+				datatype2=VM68K_UNKNOWN;
+				retval=VM68K_OK;
+				switch ((opcode>>12)&0x3)
+				{
+					case 1: datatype2=VM68K_BYTE;break;
+					case 3: datatype2=VM68K_WORD;break;
+					case 2: datatype2=VM68K_LONG;break;
+					default: retval=VM68K_NOK_UNKNOWN_INSTRUCTION;
+				}
+				addrmode_dest=(opcode>>6)&0x7;
+				if (retval==VM68K_OK) retval=vm68k_resolve_ea(pVM68k,&next,datatype2,addrmode,reg2,VM68K_LEGAL_ALL,&ea);
+				if (retval==VM68K_OK) retval=vm68k_fetchoperand(pVM68k,0,datatype2,ea,&operand2);
+
+
+				// TODO: I had a problem here, when the addrmode was 7/4 and the size was BYTE. lets see what happens.
+				if (retval==VM68K_OK) retval=vm68k_resolve_ea(pVM68k,&next,datatype2,addrmode_dest,reg1,(instruction==VM68K_INST_MOVE)?VM68K_LEGAL_DATAALTERATE:VM68K_LEGAL_ALL,&ea_dest);
+				if (retval==VM68K_OK) result=operand2;
+				if (retval==VM68K_OK && instruction!=VM68K_INST_MOVEA) retval=vm68k_calculateflags(&next,FLAGS_LOGIC,datatype2,0,operand2,result);
+
+				if (retval==VM68K_OK) retval=vm68k_storeresult(pVM68k,&next,datatype2,ea_dest,result);
 			}
-			addrmode_dest=(opcode>>6)&0x7;
-			if (retval==VM68K_OK) retval=vm68k_resolve_ea(pVM68k,&next,datatype2,addrmode,reg2,VM68K_LEGAL_ALL,&ea);
-			if (retval==VM68K_OK) retval=vm68k_fetchoperand(pVM68k,0,datatype2,ea,&operand2);	
-
-
-			// TODO: I had a problem here, when the addrmode was 7/4 and the size was BYTE. lets see what happens.
-			if (retval==VM68K_OK) retval=vm68k_resolve_ea(pVM68k,&next,datatype2,addrmode_dest,reg1,(instruction==VM68K_INST_MOVE)?VM68K_LEGAL_DATAALTERATE:VM68K_LEGAL_ALL,&ea_dest);
-			if (retval==VM68K_OK) result=operand2;
-			if (retval==VM68K_OK && instruction!=VM68K_INST_MOVEA) retval=vm68k_calculateflags(&next,FLAGS_LOGIC,datatype2,0,operand2,result);
-			
-			if (retval==VM68K_OK) retval=vm68k_storeresult(pVM68k,&next,datatype2,ea_dest,result);
-		}
-		break;
+			break;
 		case VM68K_INST_NEG:
 		case VM68K_INST_NEGX:
 		case VM68K_INST_NOT:
-		{
-			retval=vm68k_resolve_ea(pVM68k,&next,datatype,addrmode,reg2,VM68K_LEGAL_DATAALTERATE,&ea);
-			if (retval==VM68K_OK) retval=vm68k_fetchoperand(pVM68k,1,datatype,ea,&operand2);
-			result=(instruction==VM68K_INST_NOT)?(~operand2):(0-operand2);
-			result=result-((instruction==VM68K_INST_NEGX)&next.xflag);
-			operand1=0;
-			if (retval==VM68K_OK) retval=vm68k_calculateflags(&next,FLAGS_LOGIC,datatype,operand1,operand2,result);
-			if (retval==VM68K_OK) retval=vm68k_storeresult(pVM68k,&next,datatype,ea,result);
-			
-		}
-		break;
+			{
+				retval=vm68k_resolve_ea(pVM68k,&next,datatype,addrmode,reg2,VM68K_LEGAL_DATAALTERATE,&ea);
+				if (retval==VM68K_OK) retval=vm68k_fetchoperand(pVM68k,1,datatype,ea,&operand2);
+				result=(instruction==VM68K_INST_NOT)?(~operand2):(0-operand2);
+				result=result-((instruction==VM68K_INST_NEGX)&next.xflag);
+				operand1=0;
+				if (retval==VM68K_OK) retval=vm68k_calculateflags(&next,FLAGS_LOGIC,datatype,operand1,operand2,result);
+				if (retval==VM68K_OK) retval=vm68k_storeresult(pVM68k,&next,datatype,ea,result);
+
+			}
+			break;
 
 		case VM68K_INST_JMP:
 		case VM68K_INST_JSR:
-		{
-			tVM68k_types	datatype2;
-			datatype2=VM68K_LONG;
-			retval=vm68k_resolve_ea(pVM68k,&next,datatype2,addrmode,reg2,VM68K_LEGAL_CONTROLADDRESSING,&ea);
-			operand2=ea;
-			if (instruction==VM68K_INST_JSR && retval==VM68K_OK)	
 			{
-				PUSHLONGTOSTACK(pVM68k,&next,(next.pcr));
+				tVM68k_types	datatype2;
+				datatype2=VM68K_LONG;
+				retval=vm68k_resolve_ea(pVM68k,&next,datatype2,addrmode,reg2,VM68K_LEGAL_CONTROLADDRESSING,&ea);
+				operand2=ea;
+				if (instruction==VM68K_INST_JSR && retval==VM68K_OK)
+				{
+					PUSHLONGTOSTACK(pVM68k,&next,(next.pcr));
+				}
+				// TODO: why this way?
+				switch (addrmode)
+				{
+					case VM68K_AM_INDIR:
+						next.pcr=operand2%pVM68k->memsize;
+						break;
+					default:
+						next.pcr=operand2;	// wonderland
+						break;
+				}
 			}
-			// TODO: why this way?
-			switch (addrmode)
-			{
-				case VM68K_AM_INDIR:
-					next.pcr=operand2%pVM68k->memsize;
-					break;
-				default:
-					next.pcr=operand2;	// wonderland
-					break;
-			}
-		}
-		break;
+			break;
 		case VM68K_INST_RTS:
 			retval=VM68K_OK;
 			POPLONGFROMSTACK(pVM68k,&next,next.pcr);
-		break;
+			break;
 		case VM68K_INST_ANDItoSR:
 		case VM68K_INST_EORItoSR:
 		case VM68K_INST_ORItoSR:
@@ -467,7 +468,7 @@ int vm68k_singlestep(void *hVM68k,unsigned short opcode)
 			operand1=0xffff;
 			switch (instruction)
 			{
-				case VM68K_INST_ANDItoCCR:	operand1&=0x1f;	
+				case VM68K_INST_ANDItoCCR:	operand1&=0x1f;
 				case VM68K_INST_ANDItoSR:	operand2&=next.sr;break;
 
 				case VM68K_INST_EORItoCCR:	operand1&=0x1f;
@@ -477,12 +478,11 @@ int vm68k_singlestep(void *hVM68k,unsigned short opcode)
 				case VM68K_INST_ORItoSR:	operand2|=next.sr;break;
 				default: retval=VM68K_NOK_UNKNOWN_INSTRUCTION;break;
 			}
-			result=operand1&operand2;
 
 			next.override_sr=1;
 			next.sr&=~operand1;
 			next.sr|=operand2;
-		break;
+			break;
 		case VM68K_INST_MOVEfromSR:
 			{
 				tVM68k_types	datatype2;
@@ -492,7 +492,7 @@ int vm68k_singlestep(void *hVM68k,unsigned short opcode)
 				if (retval==VM68K_OK) retval=vm68k_storeresult(pVM68k,&next,datatype2,ea,result);
 			}
 			break;
-	
+
 		case VM68K_INST_MOVEtoCCR:
 		case VM68K_INST_MOVEtoSR:
 			{
@@ -506,7 +506,7 @@ int vm68k_singlestep(void *hVM68k,unsigned short opcode)
 					next.sr=(instruction==VM68K_INST_MOVEtoCCR)?((next.sr&0xffe0)|(operand2&0x1f)):operand2;
 				} 
 			}
-		break;
+			break;
 		case VM68K_INST_MOVEMregtomem:
 			{
 				tVM68k_types datatype2;
@@ -530,7 +530,7 @@ int vm68k_singlestep(void *hVM68k,unsigned short opcode)
 							if (datatype2==VM68K_LONG) PUSHLONGTOSTACK(pVM68k,&next,pVM68k->a[7-i]);
 						}
 						bitmask>>=1;
-					}	
+					}
 					for (i=0;i<8;i++)
 					{
 						if (bitmask&1)
@@ -542,8 +542,8 @@ int vm68k_singlestep(void *hVM68k,unsigned short opcode)
 						bitmask>>=1;
 					}
 				}
-			}	
-		break;
+			}
+			break;
 		case VM68K_INST_MOVEMmemtoreg:
 			{
 				tVM68k_types datatype2;
@@ -572,7 +572,7 @@ int vm68k_singlestep(void *hVM68k,unsigned short opcode)
 							}
 						}
 						bitmask>>=1;
-					}	
+					}
 					for (i=0;i<8;i++)
 					{
 						if (bitmask&1)
@@ -591,220 +591,220 @@ int vm68k_singlestep(void *hVM68k,unsigned short opcode)
 						bitmask>>=1;
 					}
 				}
-			}	
-		break;
+			}
+			break;
 		case VM68K_INST_EXT:
-		{
-			tVM68k_types datatype2=VM68K_UNKNOWN;
-			switch ((opcode>>6)&0x3)
 			{
-				case 2:	datatype2=VM68K_WORD;break;
-				case 3:	datatype2=VM68K_LONG;break;
+				tVM68k_types datatype2=VM68K_UNKNOWN;
+				switch ((opcode>>6)&0x3)
+				{
+					case 2:	datatype2=VM68K_WORD;break;
+					case 3:	datatype2=VM68K_LONG;break;
+				}
+				switch (datatype2)
+				{
+					case VM68K_WORD:	result=(tVM68k_sword)((tVM68k_sbyte)(pVM68k->d[reg2]&  0xff));retval=VM68K_OK;
+								result=((pVM68k->d[reg2])&0xffff0000)|(((tVM68k_ulong)result)&0xffff);
+								break;
+					case VM68K_LONG:	result=(tVM68k_slong)((tVM68k_sword)(pVM68k->d[reg2]&0xffff));retval=VM68K_OK;break;
+					default: retval=VM68K_NOK_UNKNOWN_INSTRUCTION;break;
+				}
+				if (retval==VM68K_OK) retval=vm68k_calculateflags(&next,FLAGS_LOGIC,datatype2,0,0,result);
+				if (retval==VM68K_OK) next.d[reg2]=result;
 			}
-			switch (datatype2)
-			{
-				case VM68K_WORD:	result=(tVM68k_sword)((tVM68k_sbyte)(pVM68k->d[reg2]&  0xff));retval=VM68K_OK;
-							result=((pVM68k->d[reg2])&0xffff0000)|(((tVM68k_ulong)result)&0xffff);
-							break;
-				case VM68K_LONG:	result=(tVM68k_slong)((tVM68k_sword)(pVM68k->d[reg2]&0xffff));retval=VM68K_OK;break;
-				default: retval=VM68K_NOK_UNKNOWN_INSTRUCTION;break;
-			}
-			if (retval==VM68K_OK) retval=vm68k_calculateflags(&next,FLAGS_LOGIC,datatype2,0,0,result);
-			if (retval==VM68K_OK) next.d[reg2]=result;
-		}
-		break;
+			break;
 		case VM68K_INST_PEA:
 			retval=vm68k_resolve_ea(pVM68k,&next,VM68K_LONG,addrmode,reg2,VM68K_LEGAL_CONTROLADDRESSING,&ea);
 			result=ea;
 			if (retval==VM68K_OK) PUSHLONGTOSTACK(pVM68k,&next,result);
-		break;
+			break;
 		case VM68K_INST_LEA:
 			retval=vm68k_resolve_ea(pVM68k,&next,VM68K_LONG,addrmode,reg2,VM68K_LEGAL_CONTROLADDRESSING,&ea);
 			result=ea%(pVM68k->memsize);
 			if (retval==VM68K_OK) retval=vm68k_storeresult(pVM68k,&next,VM68K_LONG,ADDRREGADDR(reg1),result);
-		break;
+			break;
 		case VM68K_INST_NOP:
 			retval=VM68K_OK;
-		break;
+			break;
 		case VM68K_INST_ASL_ASR:
 		case VM68K_INST_LSL_LSR:
 		case VM68K_INST_ROL_ROR:
 		case VM68K_INST_ROXL_ROXR:
-		{
-			tVM68k_types datatype2;
-			tVM68k_ubyte count;
-			tVM68k_bool direction;
-			tVM68k_bool msb;
-			tVM68k_bool lsb;
-			tVM68k_ubyte bitnum;
-			direction=(opcode>>8)&1;	// 0=right. 1=left.
-			bitnum=8;
-			if (datatype==VM68K_UNKNOWN)	// memory shift
 			{
-				datatype2=VM68K_WORD;
-				count=1;
-				retval=vm68k_resolve_ea(pVM68k,&next,VM68K_LONG,addrmode,reg2,VM68K_LEGAL_MEMORYALTERATE,&ea);
-			} else {
-				datatype2=datatype;
-				if ((opcode>>5)&1) 
+				tVM68k_types datatype2;
+				tVM68k_ubyte count;
+				tVM68k_bool direction;
+				tVM68k_bool msb;
+				tVM68k_bool lsb;
+				tVM68k_ubyte bitnum;
+				direction=(opcode>>8)&1;	// 0=right. 1=left.
+				bitnum=8;
+				if (datatype==VM68K_UNKNOWN)	// memory shift
 				{
-					count=pVM68k->d[reg1]%64; 
-				}
-				else // i/r=1 -> register. i/r=0 -> immedate
-				{
-					count=reg1;
-					if (count==0) count=8;
-				}
-				retval=VM68K_OK;
-				ea=DATAREGADDR(reg2);
-			}
-			if (retval==VM68K_OK) retval=vm68k_fetchoperand(pVM68k,0,datatype,ea,&operand2);
-			switch (datatype2)
-			{
-				case VM68K_BYTE: bitnum= 8;break;
-				case VM68K_WORD: bitnum=16;break;
-				case VM68K_LONG: bitnum=32;break;
-				default: retval=VM68K_NOK_UNKNOWN_INSTRUCTION;break;
-			}
-			next.vflag=0;
-			for (i=0;i<count;i++)
-			{
-				tVM68k_bool prevmsb;
-				prevmsb=msb=(operand2>>(bitnum-1))&1;
-				lsb=operand2&1;
-				if (direction)	// left shift
-				{
-					operand2<<=1;
-					switch (instruction)
+					datatype2=VM68K_WORD;
+					count=1;
+					retval=vm68k_resolve_ea(pVM68k,&next,VM68K_LONG,addrmode,reg2,VM68K_LEGAL_MEMORYALTERATE,&ea);
+				} else {
+					datatype2=datatype;
+					if ((opcode>>5)&1) 
 					{
-						case VM68K_INST_ASL_ASR:
-						case VM68K_INST_LSL_LSR:	lsb=0;break;
-						case VM68K_INST_ROL_ROR:	lsb=msb;break;
-						case VM68K_INST_ROXL_ROXR:	lsb=next.xflag;break;
-						default: retval=VM68K_NOK_UNKNOWN_INSTRUCTION;break;
+						count=pVM68k->d[reg1]%64; 
 					}
-					operand2|=lsb;
-					next.cflag=next.xflag=msb;
-					// FIXME: reallY???
-					if (instruction!=VM68K_INST_ASL_ASR) next.vflag|=(prevmsb^(operand2>>(bitnum-1)))&1;	// set overflow flag if the msb is changed at any time.
-				} else {	/// right shift
-					operand2>>=1;
-					switch (instruction)
+					else // i/r=1 -> register. i/r=0 -> immedate
 					{
-						case VM68K_INST_ASL_ASR:	msb=msb&1;break;
-						case VM68K_INST_LSL_LSR:	msb=0;break;
-						case VM68K_INST_ROL_ROR:	msb=lsb;break;
-						case VM68K_INST_ROXL_ROXR:	msb=next.xflag;break;
-						default: retval=VM68K_NOK_UNKNOWN_INSTRUCTION;break;
+						count=reg1;
+						if (count==0) count=8;
 					}
-					operand2|=(msb<<(bitnum-1));
-					next.cflag=next.xflag=lsb;
+					retval=VM68K_OK;
+					ea=DATAREGADDR(reg2);
+				}
+				if (retval==VM68K_OK) retval=vm68k_fetchoperand(pVM68k,0,datatype,ea,&operand2);
+				switch (datatype2)
+				{
+					case VM68K_BYTE: bitnum= 8;break;
+					case VM68K_WORD: bitnum=16;break;
+					case VM68K_LONG: bitnum=32;break;
+					default: retval=VM68K_NOK_UNKNOWN_INSTRUCTION;break;
+				}
+				next.vflag=0;
+				for (i=0;i<count;i++)
+				{
+					tVM68k_bool prevmsb;
+					prevmsb=msb=(operand2>>(bitnum-1))&1;
+					lsb=operand2&1;
+					if (direction)	// left shift
+					{
+						operand2<<=1;
+						switch (instruction)
+						{
+							case VM68K_INST_ASL_ASR:
+							case VM68K_INST_LSL_LSR:	lsb=0;break;
+							case VM68K_INST_ROL_ROR:	lsb=msb;break;
+							case VM68K_INST_ROXL_ROXR:	lsb=next.xflag;break;
+							default: retval=VM68K_NOK_UNKNOWN_INSTRUCTION;break;
+						}
+						operand2|=lsb;
+						next.cflag=next.xflag=msb;
+						// FIXME: reallY???
+						if (instruction!=VM68K_INST_ASL_ASR) next.vflag|=(prevmsb^(operand2>>(bitnum-1)))&1;	// set overflow flag if the msb is changed at any time.
+					} else {	/// right shift
+						operand2>>=1;
+						switch (instruction)
+						{
+							case VM68K_INST_ASL_ASR:	msb=msb&1;break;
+							case VM68K_INST_LSL_LSR:	msb=0;break;
+							case VM68K_INST_ROL_ROR:	msb=lsb;break;
+							case VM68K_INST_ROXL_ROXR:	msb=next.xflag;break;
+							default: retval=VM68K_NOK_UNKNOWN_INSTRUCTION;break;
+						}
+						operand2|=(msb<<(bitnum-1));
+						next.cflag=next.xflag=lsb;
 
+					}
 				}
+				result=operand2;
+				if (retval==VM68K_OK) retval=vm68k_calculateflags(&next,FLAGN|FLAGZ,datatype2,0,operand2,result);
+				if (retval==VM68K_OK) retval=vm68k_storeresult(pVM68k,&next,datatype2,ea,result);
 			}
-			result=operand2;
-			if (retval==VM68K_OK) retval=vm68k_calculateflags(&next,FLAGN|FLAGZ,datatype2,0,operand2,result);
-			if (retval==VM68K_OK) retval=vm68k_storeresult(pVM68k,&next,datatype2,ea,result);
-		}
-		break;
+			break;
 		case VM68K_INST_BCLR:
 		case VM68K_INST_BCHG:
 		case VM68K_INST_BSET:
 		case VM68K_INST_BTST:
-		{
-			tVM68k_ubyte bitnum;
-			tVM68k_types datatype2;
-			if (addrmode==VM68K_AM_DATAREG)
 			{
-				datatype2=VM68K_LONG;
-				bitnum=32;
-			} else {
-				datatype2=VM68K_BYTE;
-				bitnum=8;
-			}
-			retval=vm68k_resolve_ea(pVM68k,&next,datatype2,addrmode,reg2,VM68K_LEGAL_DATAALTERATE,&ea);
-			if (retval==VM68K_OK) retval=vm68k_fetchoperand(pVM68k,0,datatype2,ea,&operand2);
-			if (retval==VM68K_OK) 
-			{
-				operand1=(1<<(next.d[reg1]%bitnum));
-				next.zflag=((operand2&operand1)==0);
-
-				switch(instruction)
+				tVM68k_ubyte bitnum;
+				tVM68k_types datatype2;
+				if (addrmode==VM68K_AM_DATAREG)
 				{
-					case VM68K_INST_BCLR: result=operand2&~operand1;break;
-					case VM68K_INST_BCHG: result=operand2^ operand1;break;
-					case VM68K_INST_BSET: result=operand2| operand1;break;
-					default: 
-							      result=0;
-							      break;
+					datatype2=VM68K_LONG;
+					bitnum=32;
+				} else {
+					datatype2=VM68K_BYTE;
+					bitnum=8;
 				}
+				retval=vm68k_resolve_ea(pVM68k,&next,datatype2,addrmode,reg2,VM68K_LEGAL_DATAALTERATE,&ea);
+				if (retval==VM68K_OK) retval=vm68k_fetchoperand(pVM68k,0,datatype2,ea,&operand2);
+				if (retval==VM68K_OK) 
+				{
+					operand1=(1<<(next.d[reg1]%bitnum));
+					next.zflag=((operand2&operand1)==0);
+
+					switch(instruction)
+					{
+						case VM68K_INST_BCLR: result=operand2&~operand1;break;
+						case VM68K_INST_BCHG: result=operand2^ operand1;break;
+						case VM68K_INST_BSET: result=operand2| operand1;break;
+						default: 
+								      result=0;
+								      break;
+					}
+				}
+				if (retval==VM68K_OK && instruction!=VM68K_INST_BTST) retval=vm68k_storeresult(pVM68k,&next,datatype2,ea,result);
 			}
-			if (retval==VM68K_OK && instruction!=VM68K_INST_BTST) retval=vm68k_storeresult(pVM68k,&next,datatype2,ea,result);
-		}	
-		break;
+			break;
 		case VM68K_INST_BCLRI:
 		case VM68K_INST_BCHGB:
 		case VM68K_INST_BSETB:
 		case VM68K_INST_BTSTB:
-		{
-			tVM68k_uword bitnum;
-			tVM68k_types datatype2;
-			bitnum=READEXTENSIONWORD(pVM68k,&next);
-			datatype2=((addrmode==VM68K_AM_DATAREG)||(addrmode==VM68K_AM_ADDRREG))?VM68K_LONG:VM68K_BYTE;
-			retval=vm68k_resolve_ea(pVM68k,&next,datatype2,addrmode,reg2,VM68K_LEGAL_DATAALTERATE,&ea);
-			if (retval==VM68K_OK) retval=vm68k_fetchoperand(pVM68k,0,datatype2,ea,&operand2);
-			if (retval==VM68K_OK)
 			{
-				operand1=(1<<(bitnum%32));
-				next.zflag=((operand2&operand1)==0);
-				switch (instruction)
+				tVM68k_uword bitnum;
+				tVM68k_types datatype2;
+				bitnum=READEXTENSIONWORD(pVM68k,&next);
+				datatype2=((addrmode==VM68K_AM_DATAREG)||(addrmode==VM68K_AM_ADDRREG))?VM68K_LONG:VM68K_BYTE;
+				retval=vm68k_resolve_ea(pVM68k,&next,datatype2,addrmode,reg2,VM68K_LEGAL_DATAALTERATE,&ea);
+				if (retval==VM68K_OK) retval=vm68k_fetchoperand(pVM68k,0,datatype2,ea,&operand2);
+				if (retval==VM68K_OK)
 				{
-					case VM68K_INST_BCLRI:	result=operand2&~operand1;break;
-					case VM68K_INST_BCHGB:	result=operand2^ operand1;break;
-					case VM68K_INST_BSETB:	result=operand2| operand1;break;
-					default:
-								result=0;
-								break;
+					operand1=(1<<(bitnum%32));
+					next.zflag=((operand2&operand1)==0);
+					switch (instruction)
+					{
+						case VM68K_INST_BCLRI:	result=operand2&~operand1;break;
+						case VM68K_INST_BCHGB:	result=operand2^ operand1;break;
+						case VM68K_INST_BSETB:	result=operand2| operand1;break;
+						default:
+									result=0;
+									break;
+					}
 				}
+				if (retval==VM68K_OK && instruction!=VM68K_INST_BTSTB) retval=vm68k_storeresult(pVM68k,&next,datatype2,ea,result);
+
 			}
-			if (retval==VM68K_OK && instruction!=VM68K_INST_BTSTB) retval=vm68k_storeresult(pVM68k,&next,datatype2,ea,result);
-				
-		}
-		break;
+			break;
 		case VM68K_INST_ADDX:
 		case VM68K_INST_SUBX:
-		{
-			tVM68k_slong ea_dest;
-			tVM68k_bool rm;
+			{
+				tVM68k_slong ea_dest;
+				tVM68k_bool rm;
 
-			rm=(opcode>>3)&1;
-			retval=vm68k_resolve_ea(pVM68k,&next,datatype,(rm?VM68K_AM_PREDEC:VM68K_AM_DATAREG),reg2,VM68K_LEGAL_AM_PREDEC|VM68K_LEGAL_AM_DATAREG,&ea);
-			if (retval==VM68K_OK) retval=vm68k_fetchoperand(pVM68k,0,datatype,ea,&operand2);
-			if (retval==VM68K_OK) retval=vm68k_resolve_ea(pVM68k,&next,datatype,(rm?VM68K_AM_PREDEC:VM68K_AM_DATAREG),reg1,VM68K_LEGAL_AM_PREDEC|VM68K_LEGAL_AM_DATAREG,&ea_dest);
-			if (retval==VM68K_OK) retval=vm68k_fetchoperand(pVM68k,0,datatype,ea,&operand1);
-			if (retval==VM68K_OK) operand1+=next.xflag;
-			
-			if (retval==VM68K_OK) if (instruction==VM68K_INST_SUBX) operand1=-operand1;
-			if (retval==VM68K_OK) result=operand1+operand2;
-			if (retval==VM68K_OK) if (result!=0) next.zflag=0;	// special case
-			if (retval==VM68K_OK) retval=vm68k_calculateflags(&next,FLAGS_ALL^FLAGZ,datatype,operand1,operand2,result);
-			if (retval==VM68K_OK) retval=vm68k_storeresult(pVM68k,&next,datatype,ea,result);
-			
-		}
-		break;
+				rm=(opcode>>3)&1;
+				retval=vm68k_resolve_ea(pVM68k,&next,datatype,(rm?VM68K_AM_PREDEC:VM68K_AM_DATAREG),reg2,VM68K_LEGAL_AM_PREDEC|VM68K_LEGAL_AM_DATAREG,&ea);
+				if (retval==VM68K_OK) retval=vm68k_fetchoperand(pVM68k,0,datatype,ea,&operand2);
+				if (retval==VM68K_OK) retval=vm68k_resolve_ea(pVM68k,&next,datatype,(rm?VM68K_AM_PREDEC:VM68K_AM_DATAREG),reg1,VM68K_LEGAL_AM_PREDEC|VM68K_LEGAL_AM_DATAREG,&ea_dest);
+				if (retval==VM68K_OK) retval=vm68k_fetchoperand(pVM68k,0,datatype,ea,&operand1);
+				if (retval==VM68K_OK) operand1+=next.xflag;
+
+				if (retval==VM68K_OK) if (instruction==VM68K_INST_SUBX) operand1=-operand1;
+				if (retval==VM68K_OK) result=operand1+operand2;
+				if (retval==VM68K_OK) if (result!=0) next.zflag=0;	// special case
+				if (retval==VM68K_OK) retval=vm68k_calculateflags(&next,FLAGS_ALL^FLAGZ,datatype,operand1,operand2,result);
+				if (retval==VM68K_OK) retval=vm68k_storeresult(pVM68k,&next,datatype,ea,result);
+
+			}
+			break;
 		case VM68K_INST_CMPM:
-		{
-			tVM68k_slong ea_dest;
+			{
+				tVM68k_slong ea_dest;
+
+				retval=vm68k_resolve_ea(pVM68k,&next,datatype,VM68K_AM_POSTINC,reg2,VM68K_LEGAL_AM_POSTINC,&ea);
+				if (retval==VM68K_OK) retval=vm68k_fetchoperand(pVM68k,1,datatype,ea,&operand2);
+				if (retval==VM68K_OK) retval=vm68k_resolve_ea(pVM68k,&next,datatype,VM68K_AM_POSTINC,reg1,VM68K_LEGAL_AM_POSTINC,&ea_dest);
+				if (retval==VM68K_OK) retval=vm68k_fetchoperand(pVM68k,1,datatype,ea_dest,&operand1);
+				if (retval==VM68K_OK) result=operand2-operand1;
+				if (retval==VM68K_OK) retval=vm68k_calculateflags2(&next,FLAGS_ALL,instruction,datatype,operand1,operand2,result);
+			}
+			break;
 
-			retval=vm68k_resolve_ea(pVM68k,&next,datatype,VM68K_AM_POSTINC,reg2,VM68K_LEGAL_AM_POSTINC,&ea);
-			if (retval==VM68K_OK) retval=vm68k_fetchoperand(pVM68k,1,datatype,ea,&operand2);
-			if (retval==VM68K_OK) retval=vm68k_resolve_ea(pVM68k,&next,datatype,VM68K_AM_POSTINC,reg1,VM68K_LEGAL_AM_POSTINC,&ea_dest);
-			if (retval==VM68K_OK) retval=vm68k_fetchoperand(pVM68k,1,datatype,ea_dest,&operand1);
-			if (retval==VM68K_OK) result=operand2-operand1;
-			if (retval==VM68K_OK) retval=vm68k_calculateflags2(&next,FLAGS_ALL,instruction,datatype,operand1,operand2,result);
-		}
-		break;
-		
 		case VM68K_INST_CLR:
 			{
 				retval=vm68k_resolve_ea(pVM68k,&next,datatype,addrmode,reg2,VM68K_LEGAL_DATAALTERATE,&ea);
@@ -813,7 +813,7 @@ int vm68k_singlestep(void *hVM68k,unsigned short opcode)
 				if (retval==VM68K_OK) retval=vm68k_storeresult(pVM68k,&next,datatype,ea,result);
 
 			}
-		break;
+			break;
 		case VM68K_INST_DBcc:
 			{
 				retval=VM68K_OK;
@@ -825,7 +825,7 @@ int vm68k_singlestep(void *hVM68k,unsigned short opcode)
 					if ((tVM68k_sword)next.d[reg2]>=0) next.pcr=pVM68k->pcr+displacement; 
 				}
 			}
-		break;
+			break;
 		case VM68K_INST_SWAP:
 			{
 				tVM68k_types datatype2;
@@ -836,12 +836,12 @@ int vm68k_singlestep(void *hVM68k,unsigned short opcode)
 				if (retval==VM68K_OK) result=((operand2>>16)&0xffff)|((operand2&0xffff)<<16);
 				if (retval==VM68K_OK) next.nflag=(result>>31)&1;
 				if (retval==VM68K_OK) next.zflag=(result==0);
-				next.cflag=0;	
+				next.cflag=0;
 				next.vflag=0;
 				if (retval==VM68K_OK) retval=vm68k_storeresult(pVM68k,&next,datatype2,ea,result);
 
-			}	
-		break;
+			}
+			break;
 		case VM68K_INST_SCC:
 			{
 				tVM68k_types datatype2;
@@ -850,7 +850,7 @@ int vm68k_singlestep(void *hVM68k,unsigned short opcode)
 				retval=vm68k_resolve_ea(pVM68k,&next,datatype2,addrmode,reg2,VM68K_LEGAL_DATAALTERATE,&ea);
 				if (retval==VM68K_OK) retval=vm68k_storeresult(pVM68k,&next,datatype2,ea,result);
 			}
-		break;
+			break;
 		case VM68K_INST_TST:
 			{
 				retval=vm68k_resolve_ea(pVM68k,&next,datatype,addrmode,reg2,VM68K_LEGAL_DATAALTERATE,&ea);
@@ -859,23 +859,23 @@ int vm68k_singlestep(void *hVM68k,unsigned short opcode)
 				if (retval==VM68K_OK) retval=vm68k_calculateflags(&next,FLAGS_LOGIC,datatype,0,0,result);
 
 			}
-		break;
+			break;
 		case VM68K_INST_UNKNOWN:
 			retval=VM68K_NOK_UNKNOWN_INSTRUCTION;
-		break;
+			break;
 		default:
-		{
+			{
 #ifdef	DEBUG_PRINT
-			char tmp[64];
-			vm68k_get_instructionname(instruction,tmp);
-			printf("UNIMPLEMENTED opcode %04X = %s\n",opcode,tmp);
+				char tmp[64];
+				vm68k_get_instructionname(instruction,tmp);
+				printf("UNIMPLEMENTED opcode %04X = %s\n",opcode,tmp);
 #else
-			printf("UNIMPLEMENTED opcode %04X\n",opcode);
+				printf("UNIMPLEMENTED opcode %04X\n",opcode);
 #endif
-			retval=VM68K_NOK_UNKNOWN_INSTRUCTION;
-		}
-		break;
-	}	
+				retval=VM68K_NOK_UNKNOWN_INSTRUCTION;
+			}
+			break;
+	}
 	if (retval==VM68K_OK)
 	{
 		pVM68k->pcr=next.pcr;
@@ -892,17 +892,17 @@ int vm68k_singlestep(void *hVM68k,unsigned short opcode)
 		}
 		for (i=0;i<8;i++)
 		{
-			pVM68k->a[i]=next.a[i];	
-			pVM68k->d[i]=next.d[i];	
+			pVM68k->a[i]=next.a[i];
+			pVM68k->d[i]=next.d[i];
 		}
 		if (next.mem_we)
 		{
 			for (i=0;i<next.mem_we;i++)
 			{
 #ifdef	DEBUG_PRINT
-				if (next.mem_size==VM68K_WORD) printf("\n\nMEMWRITE WORD %04X @ %04x\n",(next.mem_value[i])&0xffff,next.mem_addr[i]);	
-				if (next.mem_size==VM68K_LONG) printf("\n\nMEMWRITE LONG %08X @ %04x\n",next.mem_value[i],next.mem_addr[i]);	
-		fflush(stdout);
+				if (next.mem_size==VM68K_WORD) printf("\n\nMEMWRITE WORD %04X @ %04x\n",(next.mem_value[i])&0xffff,next.mem_addr[i]);
+				if (next.mem_size==VM68K_LONG) printf("\n\nMEMWRITE LONG %08X @ %04x\n",next.mem_value[i],next.mem_addr[i]);
+				fflush(stdout);
 #endif
 				switch(next.mem_size)
 				{
@@ -961,7 +961,7 @@ int vm68k_getNextOpcode(void* hVM68k,unsigned short* opcode)
 		fflush(stdout);
 	}
 #endif
-	return VM68K_OK;	
+	return VM68K_OK;
 }
 
 int vm68k_getpSharedMem(void* hVM68k,void** pSharedMem,int* bytes)
