@@ -1,30 +1,30 @@
 /*
 
-   Copyright 2023, dettus@dettus.net
+Copyright 2023, dettus@dettus.net
 
-   Redistribution and use in source and binary forms, with or without modification,
-   are permitted provided that the following conditions are met:
+Redistribution and use in source and binary forms, with or without modification,
+are permitted provided that the following conditions are met:
 
-   1. Redistributions of source code must retain the above copyright notice, this 
+1. Redistributions of source code must retain the above copyright notice, this 
    list of conditions and the following disclaimer.
 
-   2. Redistributions in binary form must reproduce the above copyright notice, 
+2. Redistributions in binary form must reproduce the above copyright notice, 
    this list of conditions and the following disclaimer in the documentation 
    and/or other materials provided with the distribution.
 
-   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
-   ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
-   WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE 
-   DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE 
-   FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
-   DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
-   SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
-   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
-   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
-   OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
+ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
+WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE 
+DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE 
+FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
+DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
+SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
+CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
+OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
+OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
- */
+*/
 
 // the purpose of this file is to read the D64 disk image files
 // and to translate them into the .mag/.gfx format.
@@ -114,7 +114,7 @@ int loader_appleii_woz_parseheader(unsigned char* pWozBuf,int wozsize,tWozInfo *
 				{
 					pWozInfo->quarterTrack[i]=x;
 				}
-			}	
+			}
 			idx+=len;
 			donemask|=1;
 		}
@@ -130,7 +130,7 @@ int loader_appleii_woz_parseheader(unsigned char* pWozBuf,int wozsize,tWozInfo *
 				pWozInfo->trackStart[i]=WOZ_BLOCKSIZE*READ_INT16LE(pWozBuf,idx2);idx2+=2;
 				idx2+=2;		//skip the block count
 				pWozInfo->trackBits[i]=READ_INT32LE(pWozBuf,idx2);idx2+=4;
-			}	
+			}
 			idx+=len;
 			donemask|=2;
 
@@ -158,30 +158,28 @@ int loader_appleii_woz_parseheader(unsigned char* pWozBuf,int wozsize,tWozInfo *
 // when the woz bit stream is synchronized, it can be interpreted as a nib stream.
 int loader_appleii_woz_synchronize(unsigned char* trackbuf,unsigned char* wozbuf,int len)
 {
-	int i;
 	unsigned char byte;
-	unsigned char bit;
 	unsigned int reg;
 	int addrcnt;
 	int datacnt;
 	int part_cnt;
 	int outidx;
-	
+	int i;
+
 
 
 	reg=0;
 	byte=0;
-	bit=0;
 	addrcnt=0;
 	datacnt=0;
 	part_cnt=0;
-	i=0;
 	outidx=0;
 	for (i=0;i<NIBTRACKSIZE;i++) trackbuf[i]=0xff;	// initialize
 	while (outidx<NIBTRACKSIZE && i<(len*2) && (part_cnt!=0 || addrcnt!=MAXSECTORS || datacnt!=MAXSECTORS))
 	{
 		int wozbyte;
 		int wozbit;
+		int bit;
 
 		wozbyte=(i%len)/8;
 		wozbit=(i%len)%8;
@@ -199,21 +197,21 @@ int loader_appleii_woz_synchronize(unsigned char* trackbuf,unsigned char* wozbuf
 				{
 					addrcnt++;
 					trackbuf[outidx++]=0xD5;		// write the preamble
-					trackbuf[outidx++]=0xAA;	
-					trackbuf[outidx++]=0x96;	
+					trackbuf[outidx++]=0xAA;
+					trackbuf[outidx++]=0x96;
 					part_cnt=ADDRBUF_SIZE+EPILOGUE_SIZE;	// collect 11 bytes 
 				}
 				if (reg==0xD5AAAD)	// data preamble found
 				{
 					datacnt++;
 					trackbuf[outidx++]=0xD5;		// write the preamble
-					trackbuf[outidx++]=0xAA;	
+					trackbuf[outidx++]=0xAA;
 					trackbuf[outidx++]=0xAD;
 					part_cnt=DATABUF_SIZE+EPILOGUE_SIZE;	// collect 346 bytes
 				}
 			} else {
 				trackbuf[outidx++]=byte;
-				part_cnt--;	
+				part_cnt--;
 			}
 			byte=0;
 		}
@@ -275,12 +273,10 @@ int loader_appleii_decodenibtrack(unsigned char* pTrackBuf,int track,unsigned ch
 	unsigned char addr_volume=0;
 	unsigned char addr_checksum=0;
 	int volumeid;
-	int foundsectors;
 	int ridx;
 	int state;
 
 	volumeid=-1;
-	foundsectors=0;
 	ridx=0;
 	state=0;
 	while (ridx<(NIBTRACKSIZE+SECTORBYTES+SECTORLSB+1+9*PREAMBLESIZE))
@@ -293,7 +289,6 @@ int loader_appleii_decodenibtrack(unsigned char* pTrackBuf,int track,unsigned ch
 					{
 						ridx+=PREAMBLE_SIZE;
 						state=1;
-						foundsectors++;
 					} else ridx++;
 				}
 				break;
@@ -339,14 +334,14 @@ int loader_appleii_decodenibtrack(unsigned char* pTrackBuf,int track,unsigned ch
 					accu=0;
 					for (j=0;j<SECTORLSB;j++)
 					{
-						accu^=loader_appleii_translatetab[pTrackBuf[ridx%NIBTRACKSIZE]-DECODEROFFS];	
+						accu^=loader_appleii_translatetab[pTrackBuf[ridx%NIBTRACKSIZE]-DECODEROFFS];
 						lsbbuf[j]=accu;
 						ridx++;
 					}
 					for (j=0;j<SECTORBYTES;j++)
 					{
 						int widx;
-						accu^=loader_appleii_translatetab[pTrackBuf[ridx%NIBTRACKSIZE]-DECODEROFFS];	
+						accu^=loader_appleii_translatetab[pTrackBuf[ridx%NIBTRACKSIZE]-DECODEROFFS];
 						widx=j+SECTORBYTES*addr_sector;
 						pDskBuf[widx]=accu;
 						pDskBuf[widx]<<=1;pDskBuf[widx]|=(1&lsbbuf[j%SECTORLSB]);lsbbuf[j%SECTORLSB]>>=1;
@@ -359,7 +354,7 @@ int loader_appleii_decodenibtrack(unsigned char* pTrackBuf,int track,unsigned ch
 				break;
 		}
 
-	}	
+	}
 	return volumeid;
 }
 
@@ -395,8 +390,8 @@ int loader_appleii_mkgfx(unsigned char *gfxbuf,int* gfxsize,int gameid,int diskc
 #define	DIR_END		0x9d5
 
 		int outidx;
-		int tracks[MAXPICTURES];
-		int sectors[MAXPICTURES];
+		int tracks[MAXPICTURES]={0};
+		int sectors[MAXPICTURES]={0};
 		int i;
 		int cnt;
 		int unhuffsize;
@@ -413,12 +408,12 @@ int loader_appleii_mkgfx(unsigned char *gfxbuf,int* gfxsize,int gameid,int diskc
 		unhuffsize=READ_INT16LE(gfxbuf,unhuffoffs);
 		treeoffs=unhuffoffs+2;
 		bitidx=treeoffs+16+16;
-		treeidx=0;	
+		treeidx=0;
 		mask=0;
 		byte=0;
 		while (outidx<unhuffsize || mask)
 		{
-			unsigned char branchl,branchr;
+			unsigned char branch1,branch0;
 			unsigned char branch;
 
 			if (mask==0x00)
@@ -427,9 +422,9 @@ int loader_appleii_mkgfx(unsigned char *gfxbuf,int* gfxsize,int gameid,int diskc
 				byte=gfxbuf[bitidx++];
 			}
 
-			branchl=gfxbuf[treeoffs+ 0+treeidx];
-			branchr=gfxbuf[treeoffs+16+treeidx];
-			branch=(byte&mask)?branchl:branchr;
+			branch1=gfxbuf[treeoffs+ 0+treeidx];
+			branch0=gfxbuf[treeoffs+16+treeidx];
+			branch=(byte&mask)?branch1:branch0;
 			mask>>=1;
 
 			if (branch&0x80)
@@ -457,7 +452,7 @@ int loader_appleii_mkgfx(unsigned char *gfxbuf,int* gfxsize,int gameid,int diskc
 			unsigned int offs;
 			offs=4+MAXPICTURES*4;
 
-			
+
 			offs+=((tracks[i+CODESECTIONS]&0x1f)<<12);
 			offs+=(sectors[i+CODESECTIONS]<<8);
 			if (tracks[i+CODESECTIONS]&0x80) offs+=pDskOffs[2];		// picture is on disk 3
@@ -472,10 +467,10 @@ int loader_appleii_mkgfx(unsigned char *gfxbuf,int* gfxsize,int gameid,int diskc
 			hotfix3>>=1;
 			WRITE_INT32BE(gfxbuf,4+i*4,offs);
 		}
-		
+
 	}
 
-	
+
 	gfxbuf[0]='M';gfxbuf[1]='a';gfxbuf[2]='P';gfxbuf[3]='8';
 
 	return 0;
@@ -522,7 +517,7 @@ int loader_appleii_readsection(unsigned char* pOut,tSection section,unsigned cha
 			{
 				rlecutoff=READ_INT16BE(tmp,0);
 				ridx=2;
-				firstsector=0;		
+				firstsector=0;
 			}
 		}
 		for (;ridx<SECTORBYTES;ridx++)
@@ -547,12 +542,12 @@ int loader_appleii_readsection(unsigned char* pOut,tSection section,unsigned cha
 			if (rle && rlecutoff==0)
 			{
 				rle=0;
-				removeendmarker=1;	
+				removeendmarker=1;
 			}
 		}
 		if (removeendmarker==1)
 		{
-			outidx-=4;	// remove the last 4 bytes	
+			outidx-=4;	// remove the last 4 bytes
 		}
 	}
 	if (outidx>section.len) outidx=section.len;
@@ -584,11 +579,50 @@ int loader_appleii_mkmag(unsigned char* magbuf,int* magsize,int gameid,unsigned
 	} tGameInfo;
 
 	const tGameInfo loader_appleii_gameInfo[4]={
-		{0x01,0x0, {0x04,0x0,0,65536,1,0},{-1,-1,-1,-1,0,0},		-1,{0x12,0x0,0,0xc000,0,0},	{0x1e,0x0,0,0xb00,0,0},	{-1,-1,-1,0,0,0},	0,"The Pawn"},	
-		{0x00,0x9, {0x03,0x9,0,65536,1,1},{-1,-1,-1,-1,0,0},		-1,{0x12,0xb,0,0xf100,0,0},	{0x21,0xc,0,0xe00,0,0},	{-1,-1,-1,0,0,0},	1,"The Guild of Thieves"},	
-
-		{0x00,0x9, {0x08,0x2,0,0x3300,1,1},{0x00,0x0,1,0xcd00,1,0},	7,{0x0c,0xc,1, 57344,0,0},	{0x1a,0xc,1, 24832,0,0},	{0x06,0x0,0,  8704,1,0},	2,"Jinxter"},
-		{0x00,0x9, {0x04,0x0,0,0x4200,1,0},{0x00,0x0,1,0xbe00,1,0},	2,{0x0b,0xe,1, 57344,0,0},	{0x19,0xe,1, 37120,0,0},	{0x08,0x2,0,  7680,1,0},	3,"Corruption"}
+		{.gamename="The Pawn",
+			.version=0,
+			.name_track=0x01,
+			.name_sector=0x0, 
+			.code_section	={.track=0x04,.sector=0x0,.disk= 0,.len=65536,.scrambled=1,.rle=0},
+			.code2_section	={.track=  -1,.sector= -1,.disk=-1,.len=   -1,.scrambled=0,.rle=0},
+			.pivot_code2=-1,
+			.string1_section={.track=0x12,.sector=0x0,.disk= 0,.len=49152,.scrambled=0,.rle=0},
+			.string2_section={.track=0x1e,.sector=0x0,.disk= 0,.len= 2816,.scrambled=0,.rle=0},
+			.dict_section	={.track=  -1,.sector= -1,.disk=-1,.len=    0,.scrambled=0,.rle=0}
+		},
+		{.gamename="The Guild of Thieves",
+			.version=1,
+			.name_track=0x00,
+			.name_sector=0x9, 
+			.code_section	={.track=0x03,.sector=0x9,.disk= 0,.len=65536,.scrambled=1,.rle=1},
+			.code2_section	={.track=  -1,.sector= -1,.disk=-1,.len=   -1,.scrambled=0,.rle=0},
+			.pivot_code2=-1,
+			.string1_section={.track=0x12,.sector=0xb,.disk= 0,.len=61696,.scrambled=0,.rle=0},
+			.string2_section={.track=0x21,.sector=0xc,.disk= 0,.len= 3584,.scrambled=0,.rle=0},
+			.dict_section	={.track=  -1,.sector= -1,.disk=-1,.len=    0,.scrambled=0,.rle=0}
+		},
+		{.gamename="Jinxter",
+			.version=2,
+			.name_track=0x00,
+			.name_sector=0x9, 
+			.code_section	={.track=0x08,.sector=0x2,.disk= 0,.len=13056,.scrambled=1,.rle=1},
+			.code2_section	={.track=0x00,.sector=0x0,.disk= 1,.len=52480,.scrambled=1,.rle=0},
+			.pivot_code2=7,
+			.string1_section={.track=0x0c,.sector=0xc,.disk= 1,.len= 57344,.scrambled=0,.rle=0},
+			.string2_section={.track=0x1a,.sector=0xc,.disk= 1,.len= 24832,.scrambled=0,.rle=0},
+			.dict_section	={.track=0x06,.sector=0x0,.disk= 0,.len=  8704,.scrambled=1,.rle=0}
+		},
+		{.gamename="Corruption",
+			.version=3,
+			.name_track=0x00,
+			.name_sector=0x9, 
+			.code_section	={.track=0x04,.sector=0x0,.disk= 0,.len=16896,.scrambled=1,.rle=0},
+			.code2_section	={.track=0x00,.sector=0x0,.disk= 1,.len=48640,.scrambled=1,.rle=0},
+			.pivot_code2=2,
+			.string1_section={.track=0x0b,.sector=0xe,.disk= 1,.len= 57344,.scrambled=0,.rle=0},
+			.string2_section={.track=0x19,.sector=0xe,.disk= 1,.len= 37120,.scrambled=0,.rle=0},
+			.dict_section	={.track=0x08,.sector=0x2,.disk= 0,.len=  7680,.scrambled=1,.rle=0}
+		}
 	};
 	{
 		int offs;
@@ -622,7 +656,7 @@ int loader_appleii_mkmag(unsigned char* magbuf,int* magsize,int gameid,unsigned
 	magidx+=string2size;
 	dictsize=loader_appleii_readsection(&magbuf[magidx],loader_appleii_gameInfo[gameid].dict_section,pDskBuf,diskcnt,pDskOffs,0);
 	magidx+=dictsize;
-	
+
 
 	{
 		int j;
@@ -657,20 +691,20 @@ int loader_appleii(char *appleiiname,
 {
 	unsigned char* pDskBuf;
 	char filename[1024];
-	unsigned char trackbuf[NIBTRACKSIZE];
+	unsigned char trackbuf[NIBTRACKSIZE]={0};
 	int i,l;
 	int j;
 	int diskcnt;
-	int volumeids[MAXDISKS];
+	int volumeids[MAXDISKS]={0};
 	int dskidx;
 	int gameid;
-	int diskoffs[MAXDISKS];
+	int diskoffs[MAXDISKS]={0};
 	tWozInfo wozInfo;
 	int retval;
 	FILE *f;
 
 #define	SIZE_NIBIMAGE	232960
-#define	SIZE_2MGIMAGE	143424	
+#define	SIZE_2MGIMAGE	143424
 #define	SIZE_DSKIMAGE	143360
 
 	pDskBuf=(unsigned char*)&gfxbuf[4+MAXPICTURES*4];
@@ -698,7 +732,7 @@ int loader_appleii(char *appleiiname,
 			fseek(f,0L,SEEK_SET);
 			n=0;
 			if (filesize==SIZE_NIBIMAGE)
-			{	
+			{
 				for (j=0;j<MAXTRACKS;j++)
 				{
 					n+=fread(trackbuf,sizeof(char),NIBTRACKSIZE,f);
@@ -722,7 +756,7 @@ int loader_appleii(char *appleiiname,
 					int dskidx0;
 					// the file is a .woz file, basically an unsynchronized .nib file with a header.
 					// the idea is to synchronize the tracks and treat it as a NIB file.
-			
+
 					// first, the wo header needs to be parsed, to find the tracks within the diskfile
 					if (loader_appleii_woz_parseheader(&pDskBuf[dskidx],filesize,&wozInfo))
 					{
@@ -741,7 +775,7 @@ int loader_appleii(char *appleiiname,
 						len=wozInfo.trackBits[quarterTrack];
 
 						if (start)
-						{	
+						{
 							loader_appleii_woz_synchronize(trackbuf,&pDskBuf[dskidx0+start],len);
 							volumeids[diskcnt]=loader_appleii_decodenibtrack(trackbuf,j,&pDskBuf[dskidx]);
 						}
@@ -761,12 +795,12 @@ int loader_appleii(char *appleiiname,
 		}
 	}
 	gameid=-1;
-	
+
 	for (i=0;i<diskcnt;i++)
 	{
 		int newgameid;
 		int disknum;
-		
+
 		disknum=-1;
 		switch(volumeids[i])
 		{
@@ -778,7 +812,7 @@ int loader_appleii(char *appleiiname,
 			case 0x73:
 			case 0x74:	newgameid=GAME_CORRUPTION;	disknum=volumeids[i]-0x72;break;
 			default:
-					return -1;
+					return disknum;
 		}
 		if (gameid==-1 || gameid==newgameid) gameid=newgameid;
 		else {
@@ -797,8 +831,8 @@ int loader_appleii(char *appleiiname,
 	}
 
 
-	retval=loader_appleii_mkmag((unsigned char*)magbuf,magsize,gameid,pDskBuf,diskcnt,diskoffs);	// since the memory for the gfx buffer includes the dskbuf, this is enough	
-	retval|=loader_appleii_mkgfx((unsigned char*)gfxbuf,gfxsize,gameid,diskcnt,diskoffs);	// since the memory for the gfx buffer includes the dskbuf, this is enough	
+	retval=loader_appleii_mkmag((unsigned char*)magbuf,magsize,gameid,pDskBuf,diskcnt,diskoffs);	// since the memory for the gfx buffer includes the dskbuf, this is enough
+	retval|=loader_appleii_mkgfx((unsigned char*)gfxbuf,gfxsize,gameid,diskcnt,diskoffs);	// since the memory for the gfx buffer includes the dskbuf, this is enough
 	if (nodoc)
 	{
 		int i;
