@@ -1,30 +1,30 @@
 /*
 
-   Copyright 2023, dettus@dettus.net
+Copyright 2023, dettus@dettus.net
 
-   Redistribution and use in source and binary forms, with or without modification,
-   are permitted provided that the following conditions are met:
+Redistribution and use in source and binary forms, with or without modification,
+are permitted provided that the following conditions are met:
 
-   1. Redistributions of source code must retain the above copyright notice, this 
+1. Redistributions of source code must retain the above copyright notice, this 
    list of conditions and the following disclaimer.
 
-   2. Redistributions in binary form must reproduce the above copyright notice, 
+2. Redistributions in binary form must reproduce the above copyright notice, 
    this list of conditions and the following disclaimer in the documentation 
    and/or other materials provided with the distribution.
 
-   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
-   ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
-   WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE 
-   DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE 
-   FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
-   DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
-   SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
-   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
-   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
-   OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
+ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
+WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE 
+DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE 
+FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
+DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
+SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
+CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
+OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
+OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
- */
+*/
 
 // the purpose of this file is to read the MS DOS Game binaries,
 // and to translate them into the .mag/.gfx format.
@@ -64,11 +64,36 @@ typedef	struct _tGames
 #define	F10PICTURES	10
 
 const tGames loader_archimedes_cGames[MAXGAMES]={
-		{"Pawn",		0,"The Pawn",			(1<<F6CODE)|            (1<<F8STRING2)|(1<<F9STRING1)|(1<<F10PICTURES),{0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31}},
-		{"GUILD",		1,"The Guild of Thieves",	(1<<F6CODE)|(1<<F7DICT)|(1<<F8STRING2)|(1<<F9STRING1)|(1<<F10PICTURES),{0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31}},
-		{"Jinxter",		2,"Jinxter",			(1<<F6CODE)|(1<<F7DICT)|(1<<F8STRING2)|(1<<F9STRING1)|(1<<F10PICTURES),{16,21,22,11, 0, 6, 3,15,24, 7,12,13, 1,28,26,17,23, 9, 4,18,25,20,10, 8,19,14, 2, 0, 0, 0, 0, 0}},
-		{"Corruption",		3,"Corruption",			(1<<F6CODE)|(1<<F7DICT)|(1<<F8STRING2)|(1<<F9STRING1)|(1<<F10PICTURES),{0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31}},
-		{"Fish!",		3,"Fish!",			(1<<F6CODE)|(1<<F7DICT)|(1<<F8STRING2)|(1<<F9STRING1)|(1<<F10PICTURES),{0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31}}
+		{.gamename="The Pawn",
+			.version=0,
+			.magicdirname="Pawn",
+			.expectedmask=(1<<F6CODE)|            (1<<F8STRING2)|(1<<F9STRING1)|(1<<F10PICTURES),
+			.pictureorder={0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31}
+		},
+		{.gamename="The Guild of Thieves",
+			.version=1,
+			.magicdirname="GUILD",
+			.expectedmask=(1<<F6CODE)|(1<<F7DICT)|(1<<F8STRING2)|(1<<F9STRING1)|(1<<F10PICTURES),
+			.pictureorder={0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31}
+		},
+		{.gamename="Jinxter",
+			.version=2,
+			.magicdirname="Jinxter",
+			.expectedmask=(1<<F6CODE)|(1<<F7DICT)|(1<<F8STRING2)|(1<<F9STRING1)|(1<<F10PICTURES),
+			.pictureorder={16,21,22,11,0,6,3,15,24,7,12,13,1,28,26,17,23,9,4,18,25,20,10,8,19,14,2,    0,0,0,0,0}
+		},
+		{.gamename="Corruption",
+			.version=3,
+			.magicdirname="Corruption",
+			.expectedmask=(1<<F6CODE)|(1<<F7DICT)|(1<<F8STRING2)|(1<<F9STRING1)|(1<<F10PICTURES),
+			.pictureorder={0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31}
+		},
+		{.gamename="Fish!",
+			.version=3,
+			.magicdirname="Fish!",
+			.expectedmask=(1<<F6CODE)|(1<<F7DICT)|(1<<F8STRING2)|(1<<F9STRING1)|(1<<F10PICTURES),
+			.pictureorder={0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31}
+		}
 };
 int loader_archimedes_findoffset(unsigned char* map,int mapsize,int sectorsize,int indicator,int indlen,int bytespermapbit,int* pStart)
 {
@@ -81,7 +106,7 @@ int loader_archimedes_findoffset(unsigned char* map,int mapsize,int sectorsize,i
 	int starti;
 	i=0;
 	status=0;
-	mask=(1<<indlen)-1;	
+	mask=(1<<indlen)-1;
 
 	sectoroffset=0;
 	// in case the last 8 bits of the indicator are set, one map entry shares the pointer to several sectors.
@@ -96,7 +121,7 @@ int loader_archimedes_findoffset(unsigned char* map,int mapsize,int sectorsize,i
 	starti=-1;
 	while (i<mapsize && indfound==0)
 	{
-		// TODO: for simplicity reasons, assume that the indicators are byte-aligned within the map.	
+		// TODO: for simplicity reasons, assume that the indicators are byte-aligned within the map.
 		// in addition to this, do not think about fragmented files (yet)
 		if (status==0)
 		{
@@ -250,12 +275,13 @@ unsigned int loader_archimedes_findfiles(unsigned char* dskimg,int dsksize,
 	// do it the lazy way. Just check if at the position where the root directory is expected to be,
 	// the magic word "Hugo" or "Nick" appears.
 #define	HUGOOFFS 0x400
-#define	NICKOFFS 0x800	
+#define	NICKOFFS 0x800
 	// for Hugo disks, this is at the beginning of sector1, so @0x401-0x404
-	if (dskimg[HUGOOFFS+1]=='H' && dskimg[HUGOOFFS+2]=='u' && dskimg[HUGOOFFS+3]=='g' && dskimg[HUGOOFFS+4]=='o') hugo0nick1=0;	
+	if (dskimg[HUGOOFFS+1]=='H' && dskimg[HUGOOFFS+2]=='u' && dskimg[HUGOOFFS+3]=='g' && dskimg[HUGOOFFS+4]=='o') hugo0nick1=0;
 	// for the Nick disks, this is at the beginning of sector2, so 0x801-0x803
 	else if (dskimg[NICKOFFS+1]=='N' && dskimg[NICKOFFS+2]=='i' && dskimg[NICKOFFS+3]=='c' && dskimg[NICKOFFS+4]=='k') hugo0nick1=1;
-	else {
+	if (hugo0nick1==-1)
+	{
 		fprintf(stderr,"unable to determine the file system type.\n");
 		return LOADER_NOK;
 	}
@@ -267,7 +293,7 @@ unsigned int loader_archimedes_findfiles(unsigned char* dskimg,int dsksize,
 	if (hugo0nick1==1)
 	{
 		int rootind;
-		
+
 		// according to //http://www.riscos.com/support/developers/prm/filecore.html#85862 
 		// the header for the "Nick" format is in the first 36 bytes of the dsk image:
 		// since the archimedes had an ARM processor, the values are little endian
@@ -294,7 +320,7 @@ unsigned int loader_archimedes_findfiles(unsigned char* dskimg,int dsksize,
 		bytespermapbit=1<<dskimg[9];
 		rootind=READ_INT32LE(dskimg,16);
 
-	
+
 		loader_archimedes_findoffset(&dskimg[ADFS_NICKMAP_OFFSET],ADFS_NICKMAP_END-ADFS_NICKMAP_OFFSET,sectorsize,rootind,indlen,bytespermapbit,&diridx);
 	}
 
@@ -302,11 +328,11 @@ unsigned int loader_archimedes_findfiles(unsigned char* dskimg,int dsksize,
 	// at this point, the location of the root directory is known.
 	// to find the files named F6, F7, F8, F9, F10, start a recursive search
 	filemask=loader_archimedes_recursivedir(dskimg,dsksize,RECURSIVEMAX,"$",	hugo0nick1,sectorsize,indlen,bytespermapbit,diridx,	pGameId,pOffsets,pLengths);
-	
+
 	if (filemask && *pGameId!=-1)
 	{
 		fprintf(stderr,"loader detected %s --> ",loader_archimedes_cGames[*pGameId].gamename);
-		if ((filemask&loader_archimedes_cGames[*pGameId].expectedmask)!=loader_archimedes_cGames[*pGameId].expectedmask)	
+		if ((filemask&loader_archimedes_cGames[*pGameId].expectedmask)!=loader_archimedes_cGames[*pGameId].expectedmask)
 		{
 			fprintf(stderr,"FAIL\n");
 			fprintf(stderr,"insufficient files on the disk. sorry\n");
@@ -347,7 +373,7 @@ int loader_archimedes_mkmag(unsigned char *dskimg,int dsksize,unsigned char* mag
 		dictsize=0;
 	}
 
-	if (nodoc)	
+	if (nodoc)
 	{
 		int i;
 		unsigned char* ptr=(unsigned char*)&magbuf[0];
@@ -362,7 +388,7 @@ int loader_archimedes_mkmag(unsigned char *dskimg,int dsksize,unsigned char* mag
 
 	*magsize=magidx;
 
-	return LOADER_OK;	
+	return LOADER_OK;
 }
 // the archimedes basically uses the same graphic format as the Amiga and the Atari.
 // all that is needed is to find the offsets to the pictures.
@@ -401,26 +427,26 @@ int loader_archimedes(char* filename,char* magbuf,int* magsize,char* gfxbuf,int*
 	int offsets[MAXFILENAMENUM+1]={0};
 	int lengths[MAXFILENAMENUM+1]={0};
 	int gameId=-1;
-	
-	
-	
+
+
+
 
 	// read the input file.
 	// actually, use the gfx buffer for that one. the data will be read linearly, the 
 	// pictures are already in the GFX1 format. all that is needed is a header and 
 	// an index.
-	newgfxsize=*gfxsize;	
+	newgfxsize=*gfxsize;
 	f=fopen(filename,"rb");
 	newgfxsize=fread(gfxbuf,sizeof(char),newgfxsize,f);
 	fclose(f);
-	
+
 
 	if (loader_archimedes_findfiles((unsigned char*)gfxbuf,newgfxsize,&gameId,offsets,lengths)!=LOADER_OK)
 	{
 		return LOADER_NOK;
 	}
 
-	// since the data is in the gfx buf, we need to generate the magbuf first.	
+	// since the data is in the gfx buf, we need to generate the magbuf first.
 	if (loader_archimedes_mkmag((unsigned char*)gfxbuf,newgfxsize,(unsigned char*)magbuf,magsize, gameId,offsets,lengths,nodoc)!=LOADER_OK)
 	{
 		return LOADER_NOK;
