@@ -1,30 +1,30 @@
 /*
 
-   Copyright 2023, dettus@dettus.net
+Copyright 2023, dettus@dettus.net
 
-   Redistribution and use in source and binary forms, with or without modification,
-   are permitted provided that the following conditions are met:
+Redistribution and use in source and binary forms, with or without modification,
+are permitted provided that the following conditions are met:
 
-   1. Redistributions of source code must retain the above copyright notice, this 
+1. Redistributions of source code must retain the above copyright notice, this 
    list of conditions and the following disclaimer.
 
-   2. Redistributions in binary form must reproduce the above copyright notice, 
+2. Redistributions in binary form must reproduce the above copyright notice, 
    this list of conditions and the following disclaimer in the documentation 
    and/or other materials provided with the distribution.
 
-   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
-   ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
-   WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE 
-   DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE 
-   FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
-   DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
-   SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
-   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
-   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
-   OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
+ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
+WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE 
+DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE 
+FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
+DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
+SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
+CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
+OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
+OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
- */
+*/
 
 // the purpose of this file is to read the Amstrad .DSK image files
 // as well as the .DSK images from the spectrum128/spectrum+3
@@ -72,18 +72,48 @@ typedef struct _tGames
 {
 	char gamename[32];
 	char gamefilename[MAXFILENAMELEN+1];
-	int version;	
+	int version;
 	unsigned short expectedsuffixes_amstradcpc;
 	unsigned short expectedsuffixes_spectrum;
 } tGames;
 const tGames loader_dsk_knownGames[NUM_GAMES]={
 	// name,game file names, version number
-	{"The Pawn",			"PAWN\0       ",0,(1<<FILESUFFIX1)|(1<<FILESUFFIX2)|(1<<FILESUFFIX3)|(1<<FILESUFFIX4),										(1<<FILESUFFIX1)|(1<<FILESUFFIX2)|(1<<FILESUFFIX3)|(1<<FILESUFFIX4)},
-	{"The Guild of Thieves",	"GUILD\0      ",1,(1<<FILESUFFIX1)|(1<<FILESUFFIX2)|(1<<FILESUFFIX3)|(1<<FILESUFFIX4)|(1<<FILESUFFIX5)|(1<<FILESUFFIX6)|(1<<FILESUFFIX7),			(1<<FILESUFFIX1)|(1<<FILESUFFIX2)|(1<<FILESUFFIX3)|(1<<FILESUFFIX4)|(1<<FILESUFFIX5)},
-	{"Jinxter",			"JINX\0       ",2,(1<<FILESUFFIX1)|(1<<FILESUFFIX2)|(1<<FILESUFFIX3)|(1<<FILESUFFIX4)|(1<<FILESUFFIX5)|(1<<FILESUFFIX6)|(1<<FILESUFFIX7)|(1<<FILESUFFIX8),	(1<<FILESUFFIX1)|(1<<FILESUFFIX2)|(1<<FILESUFFIX3)|(1<<FILESUFFIX4)|(1<<FILESUFFIX5)},
-	{"Corruption",			"CORR\0       ",3,(1<<FILESUFFIX1)|(1<<FILESUFFIX2)|(1<<FILESUFFIX3)|(1<<FILESUFFIX4)|(1<<FILESUFFIX5)|(1<<FILESUFFIX6)|(1<<FILESUFFIX7)|(1<<FILESUFFIX8),	(1<<FILESUFFIX1)|(1<<FILESUFFIX2)|(1<<FILESUFFIX3)|(1<<FILESUFFIX4)|(1<<FILESUFFIX5)},
-	{"Fish! or Myth (close enough)","FILE\0	      ",3,(1<<FILESUFFIX1)|(1<<FILESUFFIX2)|(1<<FILESUFFIX3)|(1<<FILESUFFIX4)|(1<<FILESUFFIX5)|(1<<FILESUFFIX6)|(1<<FILESUFFIX7)|(1<<FILESUFFIX8),	(1<<FILESUFFIX1)|(1<<FILESUFFIX2)|(1<<FILESUFFIX3)|(1<<FILESUFFIX4)|(1<<FILESUFFIX5)},
-	{"Myth",			"????\0       ",3,(1<<FILESUFFIX1)|(1<<FILESUFFIX2)|(1<<FILESUFFIX3)|(1<<FILESUFFIX4)|(1<<FILESUFFIX5)|(1<<FILESUFFIX6)|(1<<FILESUFFIX7)|(1<<FILESUFFIX8),	(1<<FILESUFFIX1)|(1<<FILESUFFIX2)|(1<<FILESUFFIX3)|(1<<FILESUFFIX4)|(1<<FILESUFFIX5)}
+	{.gamename="The Pawn",
+		.gamefilename="PAWN",
+		.version=0,
+		.expectedsuffixes_amstradcpc=(1<<FILESUFFIX1)|(1<<FILESUFFIX2)|(1<<FILESUFFIX3)|(1<<FILESUFFIX4),
+		.expectedsuffixes_spectrum  =(1<<FILESUFFIX1)|(1<<FILESUFFIX2)|(1<<FILESUFFIX3)|(1<<FILESUFFIX4)
+	},
+	{.gamename="The Guild of Thieves",
+		.gamefilename="GUILD",
+		.version=1,
+		.expectedsuffixes_amstradcpc=(1<<FILESUFFIX1)|(1<<FILESUFFIX2)|(1<<FILESUFFIX3)|(1<<FILESUFFIX4)|(1<<FILESUFFIX5)|(1<<FILESUFFIX6)|(1<<FILESUFFIX7),
+		.expectedsuffixes_spectrum  =(1<<FILESUFFIX1)|(1<<FILESUFFIX2)|(1<<FILESUFFIX3)|(1<<FILESUFFIX4)|(1<<FILESUFFIX5)
+	},
+	{.gamename="Jinxter",
+		.gamefilename="JINX",
+		.version=2,
+		.expectedsuffixes_amstradcpc=(1<<FILESUFFIX1)|(1<<FILESUFFIX2)|(1<<FILESUFFIX3)|(1<<FILESUFFIX4)|(1<<FILESUFFIX5)|(1<<FILESUFFIX6)|(1<<FILESUFFIX7)|(1<<FILESUFFIX8),
+		.expectedsuffixes_spectrum  =(1<<FILESUFFIX1)|(1<<FILESUFFIX2)|(1<<FILESUFFIX3)|(1<<FILESUFFIX4)|(1<<FILESUFFIX5)
+	},
+	{.gamename="Corruption",
+		.gamefilename="CORR",
+		.version=3,
+		.expectedsuffixes_amstradcpc=(1<<FILESUFFIX1)|(1<<FILESUFFIX2)|(1<<FILESUFFIX3)|(1<<FILESUFFIX4)|(1<<FILESUFFIX5)|(1<<FILESUFFIX6)|(1<<FILESUFFIX7)|(1<<FILESUFFIX8),
+		.expectedsuffixes_spectrum=(1<<FILESUFFIX1)|(1<<FILESUFFIX2)|(1<<FILESUFFIX3)|(1<<FILESUFFIX4)|(1<<FILESUFFIX5)
+	},
+	{.gamename="Fish! or Myth (close enough)",
+		.gamefilename="FILE",
+		.version=3,
+		.expectedsuffixes_amstradcpc=(1<<FILESUFFIX1)|(1<<FILESUFFIX2)|(1<<FILESUFFIX3)|(1<<FILESUFFIX4)|(1<<FILESUFFIX5)|(1<<FILESUFFIX6)|(1<<FILESUFFIX7)|(1<<FILESUFFIX8),
+		.expectedsuffixes_spectrum=(1<<FILESUFFIX1)|(1<<FILESUFFIX2)|(1<<FILESUFFIX3)|(1<<FILESUFFIX4)|(1<<FILESUFFIX5)
+	},
+	{.gamename="Myth",
+		.gamefilename="????",
+		.version=3,
+		.expectedsuffixes_amstradcpc=(1<<FILESUFFIX1)|(1<<FILESUFFIX2)|(1<<FILESUFFIX3)|(1<<FILESUFFIX4)|(1<<FILESUFFIX5)|(1<<FILESUFFIX6)|(1<<FILESUFFIX7)|(1<<FILESUFFIX8),
+		.expectedsuffixes_spectrum=(1<<FILESUFFIX1)|(1<<FILESUFFIX2)|(1<<FILESUFFIX3)|(1<<FILESUFFIX4)|(1<<FILESUFFIX5)
+	}
 };
 
 
@@ -130,7 +160,7 @@ int loader_dsk_readfile(unsigned char* inputbuf,unsigned char* outputbuf,int fil
 					outputidx+=sectorsize;
 				}
 			}
-		}	
+		}
 	}
 	return outputidx;
 
@@ -235,7 +265,7 @@ int loader_dsk_spectrum_mag(unsigned char* magbuf,int* magsize,
 	dictsize=loader_dsk_readfile(diskimage,tmpbuf,FILESUFFIX4,pDirEntries,entrycnt,sectorsize);
 	dictsize=loader_common_unhuffer(tmpbuf,dictsize,&magbuf[outputidx]);
 	outputidx+=dictsize;
-	
+
 	version=loader_dsk_knownGames[gamedetected].version;
 	if (nodoc)
 	{
@@ -268,9 +298,9 @@ int loader_dsk_amstradcpc_gfx(
 	version=loader_dsk_knownGames[gamedetected].version;
 
 	outputidx=0;
-	gfxbuf[outputidx++]='M';	
-	gfxbuf[outputidx++]='a';	
-	gfxbuf[outputidx++]='P';	
+	gfxbuf[outputidx++]='M';
+	gfxbuf[outputidx++]='a';
+	gfxbuf[outputidx++]='P';
 	gfxbuf[outputidx++]='6';
 	outputidx0=outputidx;
 	if (version==0)
@@ -297,8 +327,9 @@ int loader_dsk_amstradcpc_gfx(
 
 	} else {
 		int idxoffs;
-		outputidx+=loader_dsk_readfile(diskimage,&gfxbuf[outputidx],FILESUFFIX4,pDirEntries,entrycnt,sectorsize);
-		outputidx=4+4*32;	// due to limitations of the readfile() function, the data being read is too much	
+		//outputidx+=loader_dsk_readfile(diskimage,&gfxbuf[outputidx],FILESUFFIX4,pDirEntries,entrycnt,sectorsize);
+		loader_dsk_readfile(diskimage,&gfxbuf[outputidx],FILESUFFIX4,pDirEntries,entrycnt,sectorsize);
+		outputidx=4+4*32;	// due to limitations of the readfile() function, the data being read is too much
 		outputidx0=outputidx;
 		outputidx+=loader_dsk_readfile(diskimage,&gfxbuf[outputidx],FILESUFFIX5,pDirEntries,entrycnt,sectorsize);
 		outputidx1=outputidx;
@@ -340,7 +371,7 @@ int loader_dsk(char* amstradcpcname,
 	int gfxsize0;
 	int diskcnt;
 	int directorysector;
-	int offsets[MAX_DISKS][MAX_SECTORNUMPERDISK];
+	int offsets[MAX_DISKS][MAX_SECTORNUMPERDISK]={{0}};
 	int retval;
 	int i,l;
 	int entrycnt;
@@ -350,7 +381,7 @@ int loader_dsk(char* amstradcpcname,
 	unsigned short foundsuffixes;
 	int blocksize;
 	tDirEntry dirEntries[MAX_DIRENTRIES];
-	gfxsize0=*gfxsize;	
+	gfxsize0=*gfxsize;
 	foundsuffixes=0;
 	sectorsize=0;
 	if (gfxsize0<4*DSK_IMAGESIZE)
@@ -420,8 +451,8 @@ int loader_dsk(char* amstradcpcname,
 			fprintf(stderr,"unable to determine the DSK format. Sorry.\n");
 			return -1;
 		}
-		
-	
+
+
 
 		tracknum=dskimage[i*DSK_IMAGESIZE+0x30];
 		sidenum=dskimage[i*DSK_IMAGESIZE+0x31];
@@ -455,7 +486,7 @@ int loader_dsk(char* amstradcpcname,
 			{
 				// 0..0x0b: Magic Word "Track..."
 				// 0x0c..0x0f: unused
-				idx+=0x0c;		// skip the magic word	
+				idx+=0x0c;		// skip the magic word
 				idx+=0x04;		// skip the header
 				track0=dskimage[idx++];
 				side0=dskimage[idx++];
@@ -570,6 +601,10 @@ int loader_dsk(char* amstradcpcname,
 		directorysector=0;
 		blocksize=MAXBLOCKSIZE;
 	}
+	if (sectorsize==0)
+	{
+		return -1;
+	}
 	for (i=0;i<diskcnt;i++)
 	{
 		int j,k,l;
@@ -601,7 +636,7 @@ int loader_dsk(char* amstradcpcname,
 							{
 								gamedetected=m;
 								validfilename=1;
-							}	
+							}
 						}
 					}
 					if (gamedetected!=-1)
@@ -615,7 +650,7 @@ int loader_dsk(char* amstradcpcname,
 							{
 								foundsuffixes|=(1<<dirEntries[entrycnt].fileID);
 							}
-						}	
+						}
 						dirEntries[entrycnt].attrs=(ptr[ 9]>>5)&4;
 						dirEntries[entrycnt].attrs|=(ptr[10]>>6)&2;
 						dirEntries[entrycnt].attrs|=(ptr[11]>>7)&1;
@@ -635,7 +670,7 @@ int loader_dsk(char* amstradcpcname,
 									dirEntries[entrycnt].offsets[l*n+m]=-1;
 								}
 							} else {
-								
+
 								for (m=0;m<n;m++)
 								{
 									dirEntries[entrycnt].offsets[l*n+m]=offsets[i][dirEntries[entrycnt].blocks[l]*n+m+directorysector];
@@ -655,7 +690,6 @@ int loader_dsk(char* amstradcpcname,
 		return 1;
 	}
 	printf("DSK Loader detected '%s'\n",loader_dsk_knownGames[gamedetected].gamename);
-	expectedsuffixes=0;
 	if (amstrad0spectrum1)
 	{
 		expectedsuffixes=loader_dsk_knownGames[gamedetected].expectedsuffixes_spectrum;
@@ -697,7 +731,7 @@ int loader_dsk(char* amstradcpcname,
 
 		*gfxsize=0;
 	} else {
-		// start with the magbuf. use the first half of the empty gfx buf as tmpbuf for the unhuff	
+		// start with the magbuf. use the first half of the empty gfx buf as tmpbuf for the unhuff
 		retval=loader_dsk_amstradcpc_mag((unsigned char*)magbuf,magsize,
 				dskimage,diskcnt,
 				(unsigned char*)gfxbuf,2*DSK_IMAGESIZE,
